/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AccountSubscriptionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#account_id AccountSubscription#account_id}
    */
    readonly accountId: string;
    /**
    * How often the subscription is renewed automatically.
    * Available values: "weekly", "monthly", "quarterly", "yearly".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#frequency AccountSubscription#frequency}
    */
    readonly frequency?: string;
    /**
    * The rate plan applied to the subscription.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#rate_plan AccountSubscription#rate_plan}
    */
    readonly ratePlan?: AccountSubscriptionRatePlan;
}
export interface AccountSubscriptionRatePlan {
    /**
    * The currency applied to the rate plan subscription.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#currency AccountSubscription#currency}
    */
    readonly currency?: string;
    /**
    * Whether this rate plan is managed externally from Cloudflare.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#externally_managed AccountSubscription#externally_managed}
    */
    readonly externallyManaged?: boolean | cdktf.IResolvable;
    /**
    * The ID of the rate plan.
    * Available values: "free", "lite", "pro", "pro_plus", "business", "enterprise", "partners_free", "partners_pro", "partners_business", "partners_enterprise".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#id AccountSubscription#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether a rate plan is enterprise-based (or newly adopted term contract).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#is_contract AccountSubscription#is_contract}
    */
    readonly isContract?: boolean | cdktf.IResolvable;
    /**
    * The full name of the rate plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#public_name AccountSubscription#public_name}
    */
    readonly publicName?: string;
    /**
    * The scope that this rate plan applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#scope AccountSubscription#scope}
    */
    readonly scope?: string;
    /**
    * The list of sets this rate plan applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#sets AccountSubscription#sets}
    */
    readonly sets?: string[];
}
export declare function accountSubscriptionRatePlanToTerraform(struct?: AccountSubscriptionRatePlan | cdktf.IResolvable): any;
export declare function accountSubscriptionRatePlanToHclTerraform(struct?: AccountSubscriptionRatePlan | cdktf.IResolvable): any;
export declare class AccountSubscriptionRatePlanOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccountSubscriptionRatePlan | cdktf.IResolvable | undefined;
    set internalValue(value: AccountSubscriptionRatePlan | cdktf.IResolvable | undefined);
    private _currency?;
    get currency(): string;
    set currency(value: string);
    resetCurrency(): void;
    get currencyInput(): string | undefined;
    private _externallyManaged?;
    get externallyManaged(): boolean | cdktf.IResolvable;
    set externallyManaged(value: boolean | cdktf.IResolvable);
    resetExternallyManaged(): void;
    get externallyManagedInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _isContract?;
    get isContract(): boolean | cdktf.IResolvable;
    set isContract(value: boolean | cdktf.IResolvable);
    resetIsContract(): void;
    get isContractInput(): boolean | cdktf.IResolvable | undefined;
    private _publicName?;
    get publicName(): string;
    set publicName(value: string);
    resetPublicName(): void;
    get publicNameInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _sets?;
    get sets(): string[];
    set sets(value: string[]);
    resetSets(): void;
    get setsInput(): string[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription cloudflare_account_subscription}
*/
export declare class AccountSubscription extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_account_subscription";
    /**
    * Generates CDKTF code for importing a AccountSubscription resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AccountSubscription to import
    * @param importFromId The id of the existing AccountSubscription that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AccountSubscription to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/account_subscription cloudflare_account_subscription} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AccountSubscriptionConfig
    */
    constructor(scope: Construct, id: string, config: AccountSubscriptionConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get currency(): string;
    get currentPeriodEnd(): string;
    get currentPeriodStart(): string;
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
    get id(): string;
    get price(): number;
    private _ratePlan;
    get ratePlan(): AccountSubscriptionRatePlanOutputReference;
    putRatePlan(value: AccountSubscriptionRatePlan): void;
    resetRatePlan(): void;
    get ratePlanInput(): cdktf.IResolvable | AccountSubscriptionRatePlan | undefined;
    get state(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
