/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CustomSslConfig extends cdktf.TerraformMetaArguments {
    /**
    * A ubiquitous bundle has the highest probability of being verified everywhere, even by clients using outdated or unusual trust stores. An optimal bundle uses the shortest chain and newest intermediates. And the force bundle verifies the chain, but does not otherwise modify it.
    * Available values: "ubiquitous", "optimal", "force".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#bundle_method CustomSsl#bundle_method}
    */
    readonly bundleMethod?: string;
    /**
    * The zone's SSL certificate or certificate and the intermediate(s).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#certificate CustomSsl#certificate}
    */
    readonly certificate: string;
    /**
    * Specify the region where your private key can be held locally for optimal TLS performance. HTTPS connections to any excluded data center will still be fully encrypted, but will incur some latency while Keyless SSL is used to complete the handshake with the nearest allowed data center. Options allow distribution to only to U.S. data centers, only to E.U. data centers, or only to highest security data centers. Default distribution is to all Cloudflare datacenters, for optimal performance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#geo_restrictions CustomSsl#geo_restrictions}
    */
    readonly geoRestrictions?: CustomSslGeoRestrictions;
    /**
    * Specify the policy that determines the region where your private key will be held locally. HTTPS connections to any excluded data center will still be fully encrypted, but will incur some latency while Keyless SSL is used to complete the handshake with the nearest allowed data center. Any combination of countries, specified by their two letter country code (https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements) can be chosen, such as 'country: IN', as well as 'region: EU' which refers to the EU region. If there are too few data centers satisfying the policy, it will be rejected.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#policy CustomSsl#policy}
    */
    readonly policy?: string;
    /**
    * The zone's private key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#private_key CustomSsl#private_key}
    */
    readonly privateKey: string;
    /**
    * The type 'legacy_custom' enables support for legacy clients which do not include SNI in the TLS handshake.
    * Available values: "legacy_custom", "sni_custom".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#type CustomSsl#type}
    */
    readonly type?: string;
    /**
    * Identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#zone_id CustomSsl#zone_id}
    */
    readonly zoneId: string;
}
export interface CustomSslGeoRestrictions {
    /**
    * Available values: "us", "eu", "highest_security".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#label CustomSsl#label}
    */
    readonly label?: string;
}
export declare function customSslGeoRestrictionsToTerraform(struct?: CustomSslGeoRestrictions | cdktf.IResolvable): any;
export declare function customSslGeoRestrictionsToHclTerraform(struct?: CustomSslGeoRestrictions | cdktf.IResolvable): any;
export declare class CustomSslGeoRestrictionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CustomSslGeoRestrictions | cdktf.IResolvable | undefined;
    set internalValue(value: CustomSslGeoRestrictions | cdktf.IResolvable | undefined);
    private _label?;
    get label(): string;
    set label(value: string);
    resetLabel(): void;
    get labelInput(): string | undefined;
}
export interface CustomSslKeylessServerTunnel {
}
export declare function customSslKeylessServerTunnelToTerraform(struct?: CustomSslKeylessServerTunnel): any;
export declare function customSslKeylessServerTunnelToHclTerraform(struct?: CustomSslKeylessServerTunnel): any;
export declare class CustomSslKeylessServerTunnelOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CustomSslKeylessServerTunnel | undefined;
    set internalValue(value: CustomSslKeylessServerTunnel | undefined);
    get privateIp(): string;
    get vnetId(): string;
}
export interface CustomSslKeylessServer {
}
export declare function customSslKeylessServerToTerraform(struct?: CustomSslKeylessServer): any;
export declare function customSslKeylessServerToHclTerraform(struct?: CustomSslKeylessServer): any;
export declare class CustomSslKeylessServerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CustomSslKeylessServer | undefined;
    set internalValue(value: CustomSslKeylessServer | undefined);
    get createdOn(): string;
    get enabled(): cdktf.IResolvable;
    get host(): string;
    get id(): string;
    get modifiedOn(): string;
    get name(): string;
    get permissions(): string[];
    get port(): number;
    get status(): string;
    private _tunnel;
    get tunnel(): CustomSslKeylessServerTunnelOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl cloudflare_custom_ssl}
*/
export declare class CustomSsl extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_custom_ssl";
    /**
    * Generates CDKTF code for importing a CustomSsl resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CustomSsl to import
    * @param importFromId The id of the existing CustomSsl that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CustomSsl to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/custom_ssl cloudflare_custom_ssl} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CustomSslConfig
    */
    constructor(scope: Construct, id: string, config: CustomSslConfig);
    private _bundleMethod?;
    get bundleMethod(): string;
    set bundleMethod(value: string);
    resetBundleMethod(): void;
    get bundleMethodInput(): string | undefined;
    private _certificate?;
    get certificate(): string;
    set certificate(value: string);
    get certificateInput(): string | undefined;
    get expiresOn(): string;
    private _geoRestrictions;
    get geoRestrictions(): CustomSslGeoRestrictionsOutputReference;
    putGeoRestrictions(value: CustomSslGeoRestrictions): void;
    resetGeoRestrictions(): void;
    get geoRestrictionsInput(): cdktf.IResolvable | CustomSslGeoRestrictions | undefined;
    get hosts(): string[];
    get id(): string;
    get issuer(): string;
    private _keylessServer;
    get keylessServer(): CustomSslKeylessServerOutputReference;
    get modifiedOn(): string;
    private _policy?;
    get policy(): string;
    set policy(value: string);
    resetPolicy(): void;
    get policyInput(): string | undefined;
    get priority(): number;
    private _privateKey?;
    get privateKey(): string;
    set privateKey(value: string);
    get privateKeyInput(): string | undefined;
    get signature(): string;
    get status(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    get uploadedOn(): string;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
