/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataCloudflareHealthcheckConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/data-sources/healthcheck#healthcheck_id DataCloudflareHealthcheck#healthcheck_id}
    */
    readonly healthcheckId?: string;
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/data-sources/healthcheck#zone_id DataCloudflareHealthcheck#zone_id}
    */
    readonly zoneId: string;
}
export interface DataCloudflareHealthcheckHttpConfig {
}
export declare function dataCloudflareHealthcheckHttpConfigToTerraform(struct?: DataCloudflareHealthcheckHttpConfig): any;
export declare function dataCloudflareHealthcheckHttpConfigToHclTerraform(struct?: DataCloudflareHealthcheckHttpConfig): any;
export declare class DataCloudflareHealthcheckHttpConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareHealthcheckHttpConfig | undefined;
    set internalValue(value: DataCloudflareHealthcheckHttpConfig | undefined);
    get allowInsecure(): cdktf.IResolvable;
    get expectedBody(): string;
    get expectedCodes(): string[];
    get followRedirects(): cdktf.IResolvable;
    private _header;
    get header(): cdktf.StringListMap;
    get method(): string;
    get path(): string;
    get port(): number;
}
export interface DataCloudflareHealthcheckTcpConfig {
}
export declare function dataCloudflareHealthcheckTcpConfigToTerraform(struct?: DataCloudflareHealthcheckTcpConfig): any;
export declare function dataCloudflareHealthcheckTcpConfigToHclTerraform(struct?: DataCloudflareHealthcheckTcpConfig): any;
export declare class DataCloudflareHealthcheckTcpConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareHealthcheckTcpConfig | undefined;
    set internalValue(value: DataCloudflareHealthcheckTcpConfig | undefined);
    get method(): string;
    get port(): number;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/data-sources/healthcheck cloudflare_healthcheck}
*/
export declare class DataCloudflareHealthcheck extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "cloudflare_healthcheck";
    /**
    * Generates CDKTF code for importing a DataCloudflareHealthcheck resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataCloudflareHealthcheck to import
    * @param importFromId The id of the existing DataCloudflareHealthcheck that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/data-sources/healthcheck#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataCloudflareHealthcheck to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/data-sources/healthcheck cloudflare_healthcheck} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataCloudflareHealthcheckConfig
    */
    constructor(scope: Construct, id: string, config: DataCloudflareHealthcheckConfig);
    get address(): string;
    get checkRegions(): string[];
    get consecutiveFails(): number;
    get consecutiveSuccesses(): number;
    get createdOn(): string;
    get description(): string;
    get failureReason(): string;
    private _healthcheckId?;
    get healthcheckId(): string;
    set healthcheckId(value: string);
    resetHealthcheckId(): void;
    get healthcheckIdInput(): string | undefined;
    private _httpConfig;
    get httpConfig(): DataCloudflareHealthcheckHttpConfigOutputReference;
    get id(): string;
    get interval(): number;
    get modifiedOn(): string;
    get name(): string;
    get retries(): number;
    get status(): string;
    get suspended(): cdktf.IResolvable;
    private _tcpConfig;
    get tcpConfig(): DataCloudflareHealthcheckTcpConfigOutputReference;
    get timeout(): number;
    get type(): string;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
