/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HostnameTlsSettingConfig extends cdktf.TerraformMetaArguments {
    /**
    * The hostname for which the tls settings are set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hostname_tls_setting#hostname HostnameTlsSetting#hostname}
    */
    readonly hostname: string;
    /**
    * The TLS Setting name.
    * Available values: "ciphers", "min_tls_version", "http2".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hostname_tls_setting#setting_id HostnameTlsSetting#setting_id}
    */
    readonly settingId: string;
    /**
    * The tls setting value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hostname_tls_setting#value HostnameTlsSetting#value}
    */
    readonly value: {
        [key: string]: any;
    };
    /**
    * Identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hostname_tls_setting#zone_id HostnameTlsSetting#zone_id}
    */
    readonly zoneId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hostname_tls_setting cloudflare_hostname_tls_setting}
*/
export declare class HostnameTlsSetting extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_hostname_tls_setting";
    /**
    * Generates CDKTF code for importing a HostnameTlsSetting resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HostnameTlsSetting to import
    * @param importFromId The id of the existing HostnameTlsSetting that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hostname_tls_setting#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HostnameTlsSetting to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hostname_tls_setting cloudflare_hostname_tls_setting} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HostnameTlsSettingConfig
    */
    constructor(scope: Construct, id: string, config: HostnameTlsSettingConfig);
    get createdAt(): string;
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    get hostnameInput(): string | undefined;
    get id(): string;
    private _settingId?;
    get settingId(): string;
    set settingId(value: string);
    get settingIdInput(): string | undefined;
    get status(): string;
    get updatedAt(): string;
    private _value?;
    get value(): {
        [key: string]: any;
    };
    set value(value: {
        [key: string]: any;
    });
    get valueInput(): {
        [key: string]: any;
    } | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
