/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HyperdriveConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Define configurations using a unique string identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#account_id HyperdriveConfig#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#caching HyperdriveConfig#caching}
    */
    readonly caching?: HyperdriveConfigCaching;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#mtls HyperdriveConfig#mtls}
    */
    readonly mtls?: HyperdriveConfigMtls;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#name HyperdriveConfig#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#origin HyperdriveConfig#origin}
    */
    readonly origin: HyperdriveConfigOrigin;
}
export interface HyperdriveConfigCaching {
    /**
    * Set to true to disable caching of SQL responses. Default is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#disabled HyperdriveConfig#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * Specify the maximum duration items should persist in the cache. Not returned if set to the default (60).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#max_age HyperdriveConfig#max_age}
    */
    readonly maxAge?: number;
    /**
    * Specify the number of seconds the cache may serve a stale response. Omitted if set to the default (15).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#stale_while_revalidate HyperdriveConfig#stale_while_revalidate}
    */
    readonly staleWhileRevalidate?: number;
}
export declare function hyperdriveConfigCachingToTerraform(struct?: HyperdriveConfigCaching | cdktf.IResolvable): any;
export declare function hyperdriveConfigCachingToHclTerraform(struct?: HyperdriveConfigCaching | cdktf.IResolvable): any;
export declare class HyperdriveConfigCachingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HyperdriveConfigCaching | cdktf.IResolvable | undefined;
    set internalValue(value: HyperdriveConfigCaching | cdktf.IResolvable | undefined);
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _maxAge?;
    get maxAge(): number;
    set maxAge(value: number);
    resetMaxAge(): void;
    get maxAgeInput(): number | undefined;
    private _staleWhileRevalidate?;
    get staleWhileRevalidate(): number;
    set staleWhileRevalidate(value: number);
    resetStaleWhileRevalidate(): void;
    get staleWhileRevalidateInput(): number | undefined;
}
export interface HyperdriveConfigMtls {
    /**
    * Define CA certificate ID obtained after uploading CA cert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#ca_certificate_id HyperdriveConfig#ca_certificate_id}
    */
    readonly caCertificateId?: string;
    /**
    * Define mTLS certificate ID obtained after uploading client cert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#mtls_certificate_id HyperdriveConfig#mtls_certificate_id}
    */
    readonly mtlsCertificateId?: string;
    /**
    * Set SSL mode to 'require', 'verify-ca', or 'verify-full' to verify the CA.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#sslmode HyperdriveConfig#sslmode}
    */
    readonly sslmode?: string;
}
export declare function hyperdriveConfigMtlsToTerraform(struct?: HyperdriveConfigMtls | cdktf.IResolvable): any;
export declare function hyperdriveConfigMtlsToHclTerraform(struct?: HyperdriveConfigMtls | cdktf.IResolvable): any;
export declare class HyperdriveConfigMtlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HyperdriveConfigMtls | cdktf.IResolvable | undefined;
    set internalValue(value: HyperdriveConfigMtls | cdktf.IResolvable | undefined);
    private _caCertificateId?;
    get caCertificateId(): string;
    set caCertificateId(value: string);
    resetCaCertificateId(): void;
    get caCertificateIdInput(): string | undefined;
    private _mtlsCertificateId?;
    get mtlsCertificateId(): string;
    set mtlsCertificateId(value: string);
    resetMtlsCertificateId(): void;
    get mtlsCertificateIdInput(): string | undefined;
    private _sslmode?;
    get sslmode(): string;
    set sslmode(value: string);
    resetSslmode(): void;
    get sslmodeInput(): string | undefined;
}
export interface HyperdriveConfigOrigin {
    /**
    * Defines the Client ID of the Access token to use when connecting to the origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#access_client_id HyperdriveConfig#access_client_id}
    */
    readonly accessClientId?: string;
    /**
    * Defines the Client Secret of the Access Token to use when connecting to the origin database. The API never returns this write-only value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#access_client_secret HyperdriveConfig#access_client_secret}
    */
    readonly accessClientSecret?: string;
    /**
    * Set the name of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#database HyperdriveConfig#database}
    */
    readonly database: string;
    /**
    * Defines the host (hostname or IP) of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#host HyperdriveConfig#host}
    */
    readonly host: string;
    /**
    * Set the password needed to access your origin database. The API never returns this write-only value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#password HyperdriveConfig#password}
    */
    readonly password: string;
    /**
    * Defines the port (default: 5432 for Postgres) of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#port HyperdriveConfig#port}
    */
    readonly port?: number;
    /**
    * Specifies the URL scheme used to connect to your origin database.
    * Available values: "postgres", "postgresql", "mysql".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#scheme HyperdriveConfig#scheme}
    */
    readonly scheme: string;
    /**
    * Set the user of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#user HyperdriveConfig#user}
    */
    readonly user: string;
}
export declare function hyperdriveConfigOriginToTerraform(struct?: HyperdriveConfigOrigin | cdktf.IResolvable): any;
export declare function hyperdriveConfigOriginToHclTerraform(struct?: HyperdriveConfigOrigin | cdktf.IResolvable): any;
export declare class HyperdriveConfigOriginOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HyperdriveConfigOrigin | cdktf.IResolvable | undefined;
    set internalValue(value: HyperdriveConfigOrigin | cdktf.IResolvable | undefined);
    private _accessClientId?;
    get accessClientId(): string;
    set accessClientId(value: string);
    resetAccessClientId(): void;
    get accessClientIdInput(): string | undefined;
    private _accessClientSecret?;
    get accessClientSecret(): string;
    set accessClientSecret(value: string);
    resetAccessClientSecret(): void;
    get accessClientSecretInput(): string | undefined;
    private _database?;
    get database(): string;
    set database(value: string);
    get databaseInput(): string | undefined;
    private _host?;
    get host(): string;
    set host(value: string);
    get hostInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    get passwordInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _scheme?;
    get scheme(): string;
    set scheme(value: string);
    get schemeInput(): string | undefined;
    private _user?;
    get user(): string;
    set user(value: string);
    get userInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config cloudflare_hyperdrive_config}
*/
export declare class HyperdriveConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_hyperdrive_config";
    /**
    * Generates CDKTF code for importing a HyperdriveConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HyperdriveConfig to import
    * @param importFromId The id of the existing HyperdriveConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HyperdriveConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/hyperdrive_config cloudflare_hyperdrive_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HyperdriveConfigConfig
    */
    constructor(scope: Construct, id: string, config: HyperdriveConfigConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _caching;
    get caching(): HyperdriveConfigCachingOutputReference;
    putCaching(value: HyperdriveConfigCaching): void;
    resetCaching(): void;
    get cachingInput(): cdktf.IResolvable | HyperdriveConfigCaching | undefined;
    get createdOn(): string;
    get id(): string;
    get modifiedOn(): string;
    private _mtls;
    get mtls(): HyperdriveConfigMtlsOutputReference;
    putMtls(value: HyperdriveConfigMtls): void;
    resetMtls(): void;
    get mtlsInput(): cdktf.IResolvable | HyperdriveConfigMtls | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _origin;
    get origin(): HyperdriveConfigOriginOutputReference;
    putOrigin(value: HyperdriveConfigOrigin): void;
    get originInput(): cdktf.IResolvable | HyperdriveConfigOrigin | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
