/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MagicWanGreTunnelConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#account_id MagicWanGreTunnel#account_id}
    */
    readonly accountId: string;
    /**
    * The IP address assigned to the Cloudflare side of the GRE tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#cloudflare_gre_endpoint MagicWanGreTunnel#cloudflare_gre_endpoint}
    */
    readonly cloudflareGreEndpoint: string;
    /**
    * The IP address assigned to the customer side of the GRE tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#customer_gre_endpoint MagicWanGreTunnel#customer_gre_endpoint}
    */
    readonly customerGreEndpoint: string;
    /**
    * An optional description of the GRE tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#description MagicWanGreTunnel#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#health_check MagicWanGreTunnel#health_check}
    */
    readonly healthCheck?: MagicWanGreTunnelHealthCheck;
    /**
    * A 31-bit prefix (/31 in CIDR notation) supporting two hosts, one for each side of the tunnel. Select the subnet from the following private IP space: 10.0.0.0–10.255.255.255, 172.16.0.0–172.31.255.255, 192.168.0.0–192.168.255.255.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#interface_address MagicWanGreTunnel#interface_address}
    */
    readonly interfaceAddress: string;
    /**
    * Maximum Transmission Unit (MTU) in bytes for the GRE tunnel. The minimum value is 576.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#mtu MagicWanGreTunnel#mtu}
    */
    readonly mtu?: number;
    /**
    * The name of the tunnel. The name cannot contain spaces or special characters, must be 15 characters or less, and cannot share a name with another GRE tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#name MagicWanGreTunnel#name}
    */
    readonly name: string;
    /**
    * Time To Live (TTL) in number of hops of the GRE tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#ttl MagicWanGreTunnel#ttl}
    */
    readonly ttl?: number;
}
export interface MagicWanGreTunnelGreTunnelHealthCheckTarget {
}
export declare function magicWanGreTunnelGreTunnelHealthCheckTargetToTerraform(struct?: MagicWanGreTunnelGreTunnelHealthCheckTarget): any;
export declare function magicWanGreTunnelGreTunnelHealthCheckTargetToHclTerraform(struct?: MagicWanGreTunnelGreTunnelHealthCheckTarget): any;
export declare class MagicWanGreTunnelGreTunnelHealthCheckTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelGreTunnelHealthCheckTarget | undefined;
    set internalValue(value: MagicWanGreTunnelGreTunnelHealthCheckTarget | undefined);
    get effective(): string;
    get saved(): string;
}
export interface MagicWanGreTunnelGreTunnelHealthCheck {
}
export declare function magicWanGreTunnelGreTunnelHealthCheckToTerraform(struct?: MagicWanGreTunnelGreTunnelHealthCheck): any;
export declare function magicWanGreTunnelGreTunnelHealthCheckToHclTerraform(struct?: MagicWanGreTunnelGreTunnelHealthCheck): any;
export declare class MagicWanGreTunnelGreTunnelHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelGreTunnelHealthCheck | undefined;
    set internalValue(value: MagicWanGreTunnelGreTunnelHealthCheck | undefined);
    get direction(): string;
    get enabled(): cdktf.IResolvable;
    get rate(): string;
    private _target;
    get target(): MagicWanGreTunnelGreTunnelHealthCheckTargetOutputReference;
    get type(): string;
}
export interface MagicWanGreTunnelGreTunnel {
}
export declare function magicWanGreTunnelGreTunnelToTerraform(struct?: MagicWanGreTunnelGreTunnel): any;
export declare function magicWanGreTunnelGreTunnelToHclTerraform(struct?: MagicWanGreTunnelGreTunnel): any;
export declare class MagicWanGreTunnelGreTunnelOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelGreTunnel | undefined;
    set internalValue(value: MagicWanGreTunnelGreTunnel | undefined);
    get cloudflareGreEndpoint(): string;
    get createdOn(): string;
    get customerGreEndpoint(): string;
    get description(): string;
    private _healthCheck;
    get healthCheck(): MagicWanGreTunnelGreTunnelHealthCheckOutputReference;
    get id(): string;
    get interfaceAddress(): string;
    get modifiedOn(): string;
    get mtu(): number;
    get name(): string;
    get ttl(): number;
}
export interface MagicWanGreTunnelHealthCheckTarget {
    /**
    * The saved health check target. Setting the value to the empty string indicates that the calculated default value will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#saved MagicWanGreTunnel#saved}
    */
    readonly saved?: string;
}
export declare function magicWanGreTunnelHealthCheckTargetToTerraform(struct?: MagicWanGreTunnelHealthCheckTarget | cdktf.IResolvable): any;
export declare function magicWanGreTunnelHealthCheckTargetToHclTerraform(struct?: MagicWanGreTunnelHealthCheckTarget | cdktf.IResolvable): any;
export declare class MagicWanGreTunnelHealthCheckTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelHealthCheckTarget | cdktf.IResolvable | undefined;
    set internalValue(value: MagicWanGreTunnelHealthCheckTarget | cdktf.IResolvable | undefined);
    get effective(): string;
    private _saved?;
    get saved(): string;
    set saved(value: string);
    resetSaved(): void;
    get savedInput(): string | undefined;
}
export interface MagicWanGreTunnelHealthCheck {
    /**
    * The direction of the flow of the healthcheck. Either unidirectional, where the probe comes to you via the tunnel and the result comes back to Cloudflare via the open Internet, or bidirectional where both the probe and result come and go via the tunnel.
    * Available values: "unidirectional", "bidirectional".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#direction MagicWanGreTunnel#direction}
    */
    readonly direction?: string;
    /**
    * Determines whether to run healthchecks for a tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#enabled MagicWanGreTunnel#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * How frequent the health check is run. The default value is `mid`.
    * Available values: "low", "mid", "high".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#rate MagicWanGreTunnel#rate}
    */
    readonly rate?: string;
    /**
    * The destination address in a request type health check. After the healthcheck is decapsulated at the customer end of the tunnel, the ICMP echo will be forwarded to this address. This field defaults to `customer_gre_endpoint address`. This field is ignored for bidirectional healthchecks as the interface_address (not assigned to the Cloudflare side of the tunnel) is used as the target. Must be in object form if the x-magic-new-hc-target header is set to true and string form if x-magic-new-hc-target is absent or set to false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#target MagicWanGreTunnel#target}
    */
    readonly target?: MagicWanGreTunnelHealthCheckTarget;
    /**
    * The type of healthcheck to run, reply or request. The default value is `reply`.
    * Available values: "reply", "request".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#type MagicWanGreTunnel#type}
    */
    readonly type?: string;
}
export declare function magicWanGreTunnelHealthCheckToTerraform(struct?: MagicWanGreTunnelHealthCheck | cdktf.IResolvable): any;
export declare function magicWanGreTunnelHealthCheckToHclTerraform(struct?: MagicWanGreTunnelHealthCheck | cdktf.IResolvable): any;
export declare class MagicWanGreTunnelHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelHealthCheck | cdktf.IResolvable | undefined;
    set internalValue(value: MagicWanGreTunnelHealthCheck | cdktf.IResolvable | undefined);
    private _direction?;
    get direction(): string;
    set direction(value: string);
    resetDirection(): void;
    get directionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _rate?;
    get rate(): string;
    set rate(value: string);
    resetRate(): void;
    get rateInput(): string | undefined;
    private _target;
    get target(): MagicWanGreTunnelHealthCheckTargetOutputReference;
    putTarget(value: MagicWanGreTunnelHealthCheckTarget): void;
    resetTarget(): void;
    get targetInput(): cdktf.IResolvable | MagicWanGreTunnelHealthCheckTarget | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export interface MagicWanGreTunnelModifiedGreTunnelHealthCheckTarget {
}
export declare function magicWanGreTunnelModifiedGreTunnelHealthCheckTargetToTerraform(struct?: MagicWanGreTunnelModifiedGreTunnelHealthCheckTarget): any;
export declare function magicWanGreTunnelModifiedGreTunnelHealthCheckTargetToHclTerraform(struct?: MagicWanGreTunnelModifiedGreTunnelHealthCheckTarget): any;
export declare class MagicWanGreTunnelModifiedGreTunnelHealthCheckTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelModifiedGreTunnelHealthCheckTarget | undefined;
    set internalValue(value: MagicWanGreTunnelModifiedGreTunnelHealthCheckTarget | undefined);
    get effective(): string;
    get saved(): string;
}
export interface MagicWanGreTunnelModifiedGreTunnelHealthCheck {
}
export declare function magicWanGreTunnelModifiedGreTunnelHealthCheckToTerraform(struct?: MagicWanGreTunnelModifiedGreTunnelHealthCheck): any;
export declare function magicWanGreTunnelModifiedGreTunnelHealthCheckToHclTerraform(struct?: MagicWanGreTunnelModifiedGreTunnelHealthCheck): any;
export declare class MagicWanGreTunnelModifiedGreTunnelHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelModifiedGreTunnelHealthCheck | undefined;
    set internalValue(value: MagicWanGreTunnelModifiedGreTunnelHealthCheck | undefined);
    get direction(): string;
    get enabled(): cdktf.IResolvable;
    get rate(): string;
    private _target;
    get target(): MagicWanGreTunnelModifiedGreTunnelHealthCheckTargetOutputReference;
    get type(): string;
}
export interface MagicWanGreTunnelModifiedGreTunnel {
}
export declare function magicWanGreTunnelModifiedGreTunnelToTerraform(struct?: MagicWanGreTunnelModifiedGreTunnel): any;
export declare function magicWanGreTunnelModifiedGreTunnelToHclTerraform(struct?: MagicWanGreTunnelModifiedGreTunnel): any;
export declare class MagicWanGreTunnelModifiedGreTunnelOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanGreTunnelModifiedGreTunnel | undefined;
    set internalValue(value: MagicWanGreTunnelModifiedGreTunnel | undefined);
    get cloudflareGreEndpoint(): string;
    get createdOn(): string;
    get customerGreEndpoint(): string;
    get description(): string;
    private _healthCheck;
    get healthCheck(): MagicWanGreTunnelModifiedGreTunnelHealthCheckOutputReference;
    get id(): string;
    get interfaceAddress(): string;
    get modifiedOn(): string;
    get mtu(): number;
    get name(): string;
    get ttl(): number;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel cloudflare_magic_wan_gre_tunnel}
*/
export declare class MagicWanGreTunnel extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_magic_wan_gre_tunnel";
    /**
    * Generates CDKTF code for importing a MagicWanGreTunnel resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MagicWanGreTunnel to import
    * @param importFromId The id of the existing MagicWanGreTunnel that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MagicWanGreTunnel to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_gre_tunnel cloudflare_magic_wan_gre_tunnel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MagicWanGreTunnelConfig
    */
    constructor(scope: Construct, id: string, config: MagicWanGreTunnelConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _cloudflareGreEndpoint?;
    get cloudflareGreEndpoint(): string;
    set cloudflareGreEndpoint(value: string);
    get cloudflareGreEndpointInput(): string | undefined;
    get createdOn(): string;
    private _customerGreEndpoint?;
    get customerGreEndpoint(): string;
    set customerGreEndpoint(value: string);
    get customerGreEndpointInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _greTunnel;
    get greTunnel(): MagicWanGreTunnelGreTunnelOutputReference;
    private _healthCheck;
    get healthCheck(): MagicWanGreTunnelHealthCheckOutputReference;
    putHealthCheck(value: MagicWanGreTunnelHealthCheck): void;
    resetHealthCheck(): void;
    get healthCheckInput(): cdktf.IResolvable | MagicWanGreTunnelHealthCheck | undefined;
    get id(): string;
    private _interfaceAddress?;
    get interfaceAddress(): string;
    set interfaceAddress(value: string);
    get interfaceAddressInput(): string | undefined;
    get modified(): cdktf.IResolvable;
    private _modifiedGreTunnel;
    get modifiedGreTunnel(): MagicWanGreTunnelModifiedGreTunnelOutputReference;
    get modifiedOn(): string;
    private _mtu?;
    get mtu(): number;
    set mtu(value: number);
    resetMtu(): void;
    get mtuInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _ttl?;
    get ttl(): number;
    set ttl(value: number);
    resetTtl(): void;
    get ttlInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
