/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MagicWanIpsecTunnelConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#account_id MagicWanIpsecTunnel#account_id}
    */
    readonly accountId: string;
    /**
    * The IP address assigned to the Cloudflare side of the IPsec tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#cloudflare_endpoint MagicWanIpsecTunnel#cloudflare_endpoint}
    */
    readonly cloudflareEndpoint: string;
    /**
    * The IP address assigned to the customer side of the IPsec tunnel. Not required, but must be set for proactive traceroutes to work.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#customer_endpoint MagicWanIpsecTunnel#customer_endpoint}
    */
    readonly customerEndpoint?: string;
    /**
    * An optional description forthe IPsec tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#description MagicWanIpsecTunnel#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#health_check MagicWanIpsecTunnel#health_check}
    */
    readonly healthCheck?: MagicWanIpsecTunnelHealthCheck;
    /**
    * A 31-bit prefix (/31 in CIDR notation) supporting two hosts, one for each side of the tunnel. Select the subnet from the following private IP space: 10.0.0.0–10.255.255.255, 172.16.0.0–172.31.255.255, 192.168.0.0–192.168.255.255.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#interface_address MagicWanIpsecTunnel#interface_address}
    */
    readonly interfaceAddress: string;
    /**
    * The name of the IPsec tunnel. The name cannot share a name with other tunnels.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#name MagicWanIpsecTunnel#name}
    */
    readonly name: string;
    /**
    * A randomly generated or provided string for use in the IPsec tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#psk MagicWanIpsecTunnel#psk}
    */
    readonly psk?: string;
    /**
    * If `true`, then IPsec replay protection will be supported in the Cloudflare-to-customer direction.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#replay_protection MagicWanIpsecTunnel#replay_protection}
    */
    readonly replayProtection?: boolean | cdktf.IResolvable;
}
export interface MagicWanIpsecTunnelHealthCheckTarget {
    /**
    * The saved health check target. Setting the value to the empty string indicates that the calculated default value will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#saved MagicWanIpsecTunnel#saved}
    */
    readonly saved?: string;
}
export declare function magicWanIpsecTunnelHealthCheckTargetToTerraform(struct?: MagicWanIpsecTunnelHealthCheckTarget | cdktf.IResolvable): any;
export declare function magicWanIpsecTunnelHealthCheckTargetToHclTerraform(struct?: MagicWanIpsecTunnelHealthCheckTarget | cdktf.IResolvable): any;
export declare class MagicWanIpsecTunnelHealthCheckTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelHealthCheckTarget | cdktf.IResolvable | undefined;
    set internalValue(value: MagicWanIpsecTunnelHealthCheckTarget | cdktf.IResolvable | undefined);
    get effective(): string;
    private _saved?;
    get saved(): string;
    set saved(value: string);
    resetSaved(): void;
    get savedInput(): string | undefined;
}
export interface MagicWanIpsecTunnelHealthCheck {
    /**
    * The direction of the flow of the healthcheck. Either unidirectional, where the probe comes to you via the tunnel and the result comes back to Cloudflare via the open Internet, or bidirectional where both the probe and result come and go via the tunnel.
    * Available values: "unidirectional", "bidirectional".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#direction MagicWanIpsecTunnel#direction}
    */
    readonly direction?: string;
    /**
    * Determines whether to run healthchecks for a tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#enabled MagicWanIpsecTunnel#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * How frequent the health check is run. The default value is `mid`.
    * Available values: "low", "mid", "high".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#rate MagicWanIpsecTunnel#rate}
    */
    readonly rate?: string;
    /**
    * The destination address in a request type health check. After the healthcheck is decapsulated at the customer end of the tunnel, the ICMP echo will be forwarded to this address. This field defaults to `customer_gre_endpoint address`. This field is ignored for bidirectional healthchecks as the interface_address (not assigned to the Cloudflare side of the tunnel) is used as the target. Must be in object form if the x-magic-new-hc-target header is set to true and string form if x-magic-new-hc-target is absent or set to false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#target MagicWanIpsecTunnel#target}
    */
    readonly target?: MagicWanIpsecTunnelHealthCheckTarget;
    /**
    * The type of healthcheck to run, reply or request. The default value is `reply`.
    * Available values: "reply", "request".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#type MagicWanIpsecTunnel#type}
    */
    readonly type?: string;
}
export declare function magicWanIpsecTunnelHealthCheckToTerraform(struct?: MagicWanIpsecTunnelHealthCheck | cdktf.IResolvable): any;
export declare function magicWanIpsecTunnelHealthCheckToHclTerraform(struct?: MagicWanIpsecTunnelHealthCheck | cdktf.IResolvable): any;
export declare class MagicWanIpsecTunnelHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelHealthCheck | cdktf.IResolvable | undefined;
    set internalValue(value: MagicWanIpsecTunnelHealthCheck | cdktf.IResolvable | undefined);
    private _direction?;
    get direction(): string;
    set direction(value: string);
    resetDirection(): void;
    get directionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _rate?;
    get rate(): string;
    set rate(value: string);
    resetRate(): void;
    get rateInput(): string | undefined;
    private _target;
    get target(): MagicWanIpsecTunnelHealthCheckTargetOutputReference;
    putTarget(value: MagicWanIpsecTunnelHealthCheckTarget): void;
    resetTarget(): void;
    get targetInput(): cdktf.IResolvable | MagicWanIpsecTunnelHealthCheckTarget | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export interface MagicWanIpsecTunnelIpsecTunnelHealthCheckTarget {
}
export declare function magicWanIpsecTunnelIpsecTunnelHealthCheckTargetToTerraform(struct?: MagicWanIpsecTunnelIpsecTunnelHealthCheckTarget): any;
export declare function magicWanIpsecTunnelIpsecTunnelHealthCheckTargetToHclTerraform(struct?: MagicWanIpsecTunnelIpsecTunnelHealthCheckTarget): any;
export declare class MagicWanIpsecTunnelIpsecTunnelHealthCheckTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelIpsecTunnelHealthCheckTarget | undefined;
    set internalValue(value: MagicWanIpsecTunnelIpsecTunnelHealthCheckTarget | undefined);
    get effective(): string;
    get saved(): string;
}
export interface MagicWanIpsecTunnelIpsecTunnelHealthCheck {
}
export declare function magicWanIpsecTunnelIpsecTunnelHealthCheckToTerraform(struct?: MagicWanIpsecTunnelIpsecTunnelHealthCheck): any;
export declare function magicWanIpsecTunnelIpsecTunnelHealthCheckToHclTerraform(struct?: MagicWanIpsecTunnelIpsecTunnelHealthCheck): any;
export declare class MagicWanIpsecTunnelIpsecTunnelHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelIpsecTunnelHealthCheck | undefined;
    set internalValue(value: MagicWanIpsecTunnelIpsecTunnelHealthCheck | undefined);
    get direction(): string;
    get enabled(): cdktf.IResolvable;
    get rate(): string;
    private _target;
    get target(): MagicWanIpsecTunnelIpsecTunnelHealthCheckTargetOutputReference;
    get type(): string;
}
export interface MagicWanIpsecTunnelIpsecTunnelPskMetadata {
}
export declare function magicWanIpsecTunnelIpsecTunnelPskMetadataToTerraform(struct?: MagicWanIpsecTunnelIpsecTunnelPskMetadata): any;
export declare function magicWanIpsecTunnelIpsecTunnelPskMetadataToHclTerraform(struct?: MagicWanIpsecTunnelIpsecTunnelPskMetadata): any;
export declare class MagicWanIpsecTunnelIpsecTunnelPskMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelIpsecTunnelPskMetadata | undefined;
    set internalValue(value: MagicWanIpsecTunnelIpsecTunnelPskMetadata | undefined);
    get lastGeneratedOn(): string;
}
export interface MagicWanIpsecTunnelIpsecTunnel {
}
export declare function magicWanIpsecTunnelIpsecTunnelToTerraform(struct?: MagicWanIpsecTunnelIpsecTunnel): any;
export declare function magicWanIpsecTunnelIpsecTunnelToHclTerraform(struct?: MagicWanIpsecTunnelIpsecTunnel): any;
export declare class MagicWanIpsecTunnelIpsecTunnelOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelIpsecTunnel | undefined;
    set internalValue(value: MagicWanIpsecTunnelIpsecTunnel | undefined);
    get allowNullCipher(): cdktf.IResolvable;
    get cloudflareEndpoint(): string;
    get createdOn(): string;
    get customerEndpoint(): string;
    get description(): string;
    private _healthCheck;
    get healthCheck(): MagicWanIpsecTunnelIpsecTunnelHealthCheckOutputReference;
    get id(): string;
    get interfaceAddress(): string;
    get modifiedOn(): string;
    get name(): string;
    private _pskMetadata;
    get pskMetadata(): MagicWanIpsecTunnelIpsecTunnelPskMetadataOutputReference;
    get replayProtection(): cdktf.IResolvable;
}
export interface MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTarget {
}
export declare function magicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTargetToTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTarget): any;
export declare function magicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTargetToHclTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTarget): any;
export declare class MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTarget | undefined;
    set internalValue(value: MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTarget | undefined);
    get effective(): string;
    get saved(): string;
}
export interface MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheck {
}
export declare function magicWanIpsecTunnelModifiedIpsecTunnelHealthCheckToTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheck): any;
export declare function magicWanIpsecTunnelModifiedIpsecTunnelHealthCheckToHclTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheck): any;
export declare class MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheck | undefined;
    set internalValue(value: MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheck | undefined);
    get direction(): string;
    get enabled(): cdktf.IResolvable;
    get rate(): string;
    private _target;
    get target(): MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckTargetOutputReference;
    get type(): string;
}
export interface MagicWanIpsecTunnelModifiedIpsecTunnelPskMetadata {
}
export declare function magicWanIpsecTunnelModifiedIpsecTunnelPskMetadataToTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnelPskMetadata): any;
export declare function magicWanIpsecTunnelModifiedIpsecTunnelPskMetadataToHclTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnelPskMetadata): any;
export declare class MagicWanIpsecTunnelModifiedIpsecTunnelPskMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelModifiedIpsecTunnelPskMetadata | undefined;
    set internalValue(value: MagicWanIpsecTunnelModifiedIpsecTunnelPskMetadata | undefined);
    get lastGeneratedOn(): string;
}
export interface MagicWanIpsecTunnelModifiedIpsecTunnel {
}
export declare function magicWanIpsecTunnelModifiedIpsecTunnelToTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnel): any;
export declare function magicWanIpsecTunnelModifiedIpsecTunnelToHclTerraform(struct?: MagicWanIpsecTunnelModifiedIpsecTunnel): any;
export declare class MagicWanIpsecTunnelModifiedIpsecTunnelOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelModifiedIpsecTunnel | undefined;
    set internalValue(value: MagicWanIpsecTunnelModifiedIpsecTunnel | undefined);
    get allowNullCipher(): cdktf.IResolvable;
    get cloudflareEndpoint(): string;
    get createdOn(): string;
    get customerEndpoint(): string;
    get description(): string;
    private _healthCheck;
    get healthCheck(): MagicWanIpsecTunnelModifiedIpsecTunnelHealthCheckOutputReference;
    get id(): string;
    get interfaceAddress(): string;
    get modifiedOn(): string;
    get name(): string;
    private _pskMetadata;
    get pskMetadata(): MagicWanIpsecTunnelModifiedIpsecTunnelPskMetadataOutputReference;
    get replayProtection(): cdktf.IResolvable;
}
export interface MagicWanIpsecTunnelPskMetadata {
}
export declare function magicWanIpsecTunnelPskMetadataToTerraform(struct?: MagicWanIpsecTunnelPskMetadata): any;
export declare function magicWanIpsecTunnelPskMetadataToHclTerraform(struct?: MagicWanIpsecTunnelPskMetadata): any;
export declare class MagicWanIpsecTunnelPskMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanIpsecTunnelPskMetadata | undefined;
    set internalValue(value: MagicWanIpsecTunnelPskMetadata | undefined);
    get lastGeneratedOn(): string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel cloudflare_magic_wan_ipsec_tunnel}
*/
export declare class MagicWanIpsecTunnel extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_magic_wan_ipsec_tunnel";
    /**
    * Generates CDKTF code for importing a MagicWanIpsecTunnel resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MagicWanIpsecTunnel to import
    * @param importFromId The id of the existing MagicWanIpsecTunnel that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MagicWanIpsecTunnel to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_ipsec_tunnel cloudflare_magic_wan_ipsec_tunnel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MagicWanIpsecTunnelConfig
    */
    constructor(scope: Construct, id: string, config: MagicWanIpsecTunnelConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get allowNullCipher(): cdktf.IResolvable;
    private _cloudflareEndpoint?;
    get cloudflareEndpoint(): string;
    set cloudflareEndpoint(value: string);
    get cloudflareEndpointInput(): string | undefined;
    get createdOn(): string;
    private _customerEndpoint?;
    get customerEndpoint(): string;
    set customerEndpoint(value: string);
    resetCustomerEndpoint(): void;
    get customerEndpointInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _healthCheck;
    get healthCheck(): MagicWanIpsecTunnelHealthCheckOutputReference;
    putHealthCheck(value: MagicWanIpsecTunnelHealthCheck): void;
    resetHealthCheck(): void;
    get healthCheckInput(): cdktf.IResolvable | MagicWanIpsecTunnelHealthCheck | undefined;
    get id(): string;
    private _interfaceAddress?;
    get interfaceAddress(): string;
    set interfaceAddress(value: string);
    get interfaceAddressInput(): string | undefined;
    private _ipsecTunnel;
    get ipsecTunnel(): MagicWanIpsecTunnelIpsecTunnelOutputReference;
    get modified(): cdktf.IResolvable;
    private _modifiedIpsecTunnel;
    get modifiedIpsecTunnel(): MagicWanIpsecTunnelModifiedIpsecTunnelOutputReference;
    get modifiedOn(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _psk?;
    get psk(): string;
    set psk(value: string);
    resetPsk(): void;
    get pskInput(): string | undefined;
    private _pskMetadata;
    get pskMetadata(): MagicWanIpsecTunnelPskMetadataOutputReference;
    private _replayProtection?;
    get replayProtection(): boolean | cdktf.IResolvable;
    set replayProtection(value: boolean | cdktf.IResolvable);
    resetReplayProtection(): void;
    get replayProtectionInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
