/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MagicWanStaticRouteConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#account_id MagicWanStaticRoute#account_id}
    */
    readonly accountId: string;
    /**
    * An optional human provided description of the static route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#description MagicWanStaticRoute#description}
    */
    readonly description?: string;
    /**
    * The next-hop IP Address for the static route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#nexthop MagicWanStaticRoute#nexthop}
    */
    readonly nexthop: string;
    /**
    * IP Prefix in Classless Inter-Domain Routing format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#prefix MagicWanStaticRoute#prefix}
    */
    readonly prefix: string;
    /**
    * Priority of the static route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#priority MagicWanStaticRoute#priority}
    */
    readonly priority: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#route MagicWanStaticRoute#route}
    */
    readonly route?: MagicWanStaticRouteRoute;
    /**
    * Used only for ECMP routes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#scope MagicWanStaticRoute#scope}
    */
    readonly scope?: MagicWanStaticRouteScope;
    /**
    * Optional weight of the ECMP scope - if provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#weight MagicWanStaticRoute#weight}
    */
    readonly weight?: number;
}
export interface MagicWanStaticRouteModifiedRouteScope {
}
export declare function magicWanStaticRouteModifiedRouteScopeToTerraform(struct?: MagicWanStaticRouteModifiedRouteScope): any;
export declare function magicWanStaticRouteModifiedRouteScopeToHclTerraform(struct?: MagicWanStaticRouteModifiedRouteScope): any;
export declare class MagicWanStaticRouteModifiedRouteScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanStaticRouteModifiedRouteScope | undefined;
    set internalValue(value: MagicWanStaticRouteModifiedRouteScope | undefined);
    get coloNames(): string[];
    get coloRegions(): string[];
}
export interface MagicWanStaticRouteModifiedRoute {
}
export declare function magicWanStaticRouteModifiedRouteToTerraform(struct?: MagicWanStaticRouteModifiedRoute): any;
export declare function magicWanStaticRouteModifiedRouteToHclTerraform(struct?: MagicWanStaticRouteModifiedRoute): any;
export declare class MagicWanStaticRouteModifiedRouteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanStaticRouteModifiedRoute | undefined;
    set internalValue(value: MagicWanStaticRouteModifiedRoute | undefined);
    get createdOn(): string;
    get description(): string;
    get id(): string;
    get modifiedOn(): string;
    get nexthop(): string;
    get prefix(): string;
    get priority(): number;
    private _scope;
    get scope(): MagicWanStaticRouteModifiedRouteScopeOutputReference;
    get weight(): number;
}
export interface MagicWanStaticRouteRouteScope {
    /**
    * List of colo names for the ECMP scope.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#colo_names MagicWanStaticRoute#colo_names}
    */
    readonly coloNames?: string[];
    /**
    * List of colo regions for the ECMP scope.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#colo_regions MagicWanStaticRoute#colo_regions}
    */
    readonly coloRegions?: string[];
}
export declare function magicWanStaticRouteRouteScopeToTerraform(struct?: MagicWanStaticRouteRouteScope | cdktf.IResolvable): any;
export declare function magicWanStaticRouteRouteScopeToHclTerraform(struct?: MagicWanStaticRouteRouteScope | cdktf.IResolvable): any;
export declare class MagicWanStaticRouteRouteScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanStaticRouteRouteScope | cdktf.IResolvable | undefined;
    set internalValue(value: MagicWanStaticRouteRouteScope | cdktf.IResolvable | undefined);
    private _coloNames?;
    get coloNames(): string[];
    set coloNames(value: string[]);
    resetColoNames(): void;
    get coloNamesInput(): string[] | undefined;
    private _coloRegions?;
    get coloRegions(): string[];
    set coloRegions(value: string[]);
    resetColoRegions(): void;
    get coloRegionsInput(): string[] | undefined;
}
export interface MagicWanStaticRouteRoute {
    /**
    * An optional human provided description of the static route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#description MagicWanStaticRoute#description}
    */
    readonly description?: string;
    /**
    * The next-hop IP Address for the static route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#nexthop MagicWanStaticRoute#nexthop}
    */
    readonly nexthop?: string;
    /**
    * IP Prefix in Classless Inter-Domain Routing format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#prefix MagicWanStaticRoute#prefix}
    */
    readonly prefix?: string;
    /**
    * Priority of the static route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#priority MagicWanStaticRoute#priority}
    */
    readonly priority?: number;
    /**
    * Used only for ECMP routes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#scope MagicWanStaticRoute#scope}
    */
    readonly scope?: MagicWanStaticRouteRouteScope;
    /**
    * Optional weight of the ECMP scope - if provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#weight MagicWanStaticRoute#weight}
    */
    readonly weight?: number;
}
export declare function magicWanStaticRouteRouteToTerraform(struct?: MagicWanStaticRouteRoute | cdktf.IResolvable): any;
export declare function magicWanStaticRouteRouteToHclTerraform(struct?: MagicWanStaticRouteRoute | cdktf.IResolvable): any;
export declare class MagicWanStaticRouteRouteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanStaticRouteRoute | cdktf.IResolvable | undefined;
    set internalValue(value: MagicWanStaticRouteRoute | cdktf.IResolvable | undefined);
    get createdOn(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    get modifiedOn(): string;
    private _nexthop?;
    get nexthop(): string;
    set nexthop(value: string);
    resetNexthop(): void;
    get nexthopInput(): string | undefined;
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
    private _priority?;
    get priority(): number;
    set priority(value: number);
    resetPriority(): void;
    get priorityInput(): number | undefined;
    private _scope;
    get scope(): MagicWanStaticRouteRouteScopeOutputReference;
    putScope(value: MagicWanStaticRouteRouteScope): void;
    resetScope(): void;
    get scopeInput(): cdktf.IResolvable | MagicWanStaticRouteRouteScope | undefined;
    private _weight?;
    get weight(): number;
    set weight(value: number);
    resetWeight(): void;
    get weightInput(): number | undefined;
}
export interface MagicWanStaticRouteScope {
    /**
    * List of colo names for the ECMP scope.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#colo_names MagicWanStaticRoute#colo_names}
    */
    readonly coloNames?: string[];
    /**
    * List of colo regions for the ECMP scope.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#colo_regions MagicWanStaticRoute#colo_regions}
    */
    readonly coloRegions?: string[];
}
export declare function magicWanStaticRouteScopeToTerraform(struct?: MagicWanStaticRouteScope | cdktf.IResolvable): any;
export declare function magicWanStaticRouteScopeToHclTerraform(struct?: MagicWanStaticRouteScope | cdktf.IResolvable): any;
export declare class MagicWanStaticRouteScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MagicWanStaticRouteScope | cdktf.IResolvable | undefined;
    set internalValue(value: MagicWanStaticRouteScope | cdktf.IResolvable | undefined);
    private _coloNames?;
    get coloNames(): string[];
    set coloNames(value: string[]);
    resetColoNames(): void;
    get coloNamesInput(): string[] | undefined;
    private _coloRegions?;
    get coloRegions(): string[];
    set coloRegions(value: string[]);
    resetColoRegions(): void;
    get coloRegionsInput(): string[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route cloudflare_magic_wan_static_route}
*/
export declare class MagicWanStaticRoute extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_magic_wan_static_route";
    /**
    * Generates CDKTF code for importing a MagicWanStaticRoute resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MagicWanStaticRoute to import
    * @param importFromId The id of the existing MagicWanStaticRoute that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MagicWanStaticRoute to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/magic_wan_static_route cloudflare_magic_wan_static_route} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MagicWanStaticRouteConfig
    */
    constructor(scope: Construct, id: string, config: MagicWanStaticRouteConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get createdOn(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    get modified(): cdktf.IResolvable;
    get modifiedOn(): string;
    private _modifiedRoute;
    get modifiedRoute(): MagicWanStaticRouteModifiedRouteOutputReference;
    private _nexthop?;
    get nexthop(): string;
    set nexthop(value: string);
    get nexthopInput(): string | undefined;
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    get prefixInput(): string | undefined;
    private _priority?;
    get priority(): number;
    set priority(value: number);
    get priorityInput(): number | undefined;
    private _route;
    get route(): MagicWanStaticRouteRouteOutputReference;
    putRoute(value: MagicWanStaticRouteRoute): void;
    resetRoute(): void;
    get routeInput(): cdktf.IResolvable | MagicWanStaticRouteRoute | undefined;
    private _scope;
    get scope(): MagicWanStaticRouteScopeOutputReference;
    putScope(value: MagicWanStaticRouteScope): void;
    resetScope(): void;
    get scopeInput(): cdktf.IResolvable | MagicWanStaticRouteScope | undefined;
    private _weight?;
    get weight(): number;
    set weight(value: number);
    resetWeight(): void;
    get weightInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
