/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WorkersScriptConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#account_id WorkersScript#account_id}
    */
    readonly accountId: string;
    /**
    * Configuration for assets within a Worker
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#assets WorkersScript#assets}
    */
    readonly assets?: WorkersScriptAssets;
    /**
    * List of bindings attached to a Worker. You can find more about bindings on our docs: https://developers.cloudflare.com/workers/configuration/multipart-upload-metadata/#bindings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#bindings WorkersScript#bindings}
    */
    readonly bindings?: WorkersScriptBindings[] | cdktf.IResolvable;
    /**
    * Name of the part in the multipart request that contains the script (e.g. the file adding a listener to the `fetch` event). Indicates a `service worker syntax` Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#body_part WorkersScript#body_part}
    */
    readonly bodyPart?: string;
    /**
    * Date indicating targeted support in the Workers runtime. Backwards incompatible fixes to the runtime following this date will not affect this Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#compatibility_date WorkersScript#compatibility_date}
    */
    readonly compatibilityDate?: string;
    /**
    * Flags that enable or disable certain features in the Workers runtime. Used to enable upcoming features or opt in or out of specific changes not included in a `compatibility_date`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#compatibility_flags WorkersScript#compatibility_flags}
    */
    readonly compatibilityFlags?: string[];
    /**
    * Module or Service Worker contents of the Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#content WorkersScript#content}
    */
    readonly content: string;
    /**
    * Retain assets which exist for a previously uploaded Worker version; used in lieu of providing a completion token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#keep_assets WorkersScript#keep_assets}
    */
    readonly keepAssets?: boolean | cdktf.IResolvable;
    /**
    * List of binding types to keep from previous_upload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#keep_bindings WorkersScript#keep_bindings}
    */
    readonly keepBindings?: string[];
    /**
    * Whether Logpush is turned on for the Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#logpush WorkersScript#logpush}
    */
    readonly logpush?: boolean | cdktf.IResolvable;
    /**
    * Name of the part in the multipart request that contains the main module (e.g. the file exporting a `fetch` handler). Indicates a `module syntax` Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#main_module WorkersScript#main_module}
    */
    readonly mainModule?: string;
    /**
    * Migrations to apply for Durable Objects associated with this Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#migrations WorkersScript#migrations}
    */
    readonly migrations?: WorkersScriptMigrations;
    /**
    * Observability settings for the Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#observability WorkersScript#observability}
    */
    readonly observability?: WorkersScriptObservability;
    /**
    * Configuration for [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#placement WorkersScript#placement}
    */
    readonly placement?: WorkersScriptPlacement;
    /**
    * Name of the script, used in URLs and route configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#script_name WorkersScript#script_name}
    */
    readonly scriptName: string;
    /**
    * List of Workers that will consume logs from the attached Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#tail_consumers WorkersScript#tail_consumers}
    */
    readonly tailConsumers?: WorkersScriptTailConsumers[] | cdktf.IResolvable;
    /**
    * Usage model for the Worker invocations.
    * Available values: "standard".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#usage_model WorkersScript#usage_model}
    */
    readonly usageModel?: string;
}
export interface WorkersScriptAssetsConfig {
    /**
    * The contents of a _headers file (used to attach custom headers on asset responses)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#_headers WorkersScript#_headers}
    */
    readonly headers?: string;
    /**
    * The contents of a _redirects file (used to apply redirects or proxy paths ahead of asset serving)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#_redirects WorkersScript#_redirects}
    */
    readonly redirects?: string;
    /**
    * Determines the redirects and rewrites of requests for HTML content.
    * Available values: "auto-trailing-slash", "force-trailing-slash", "drop-trailing-slash", "none".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#html_handling WorkersScript#html_handling}
    */
    readonly htmlHandling?: string;
    /**
    * Determines the response when a request does not match a static asset, and there is no Worker script.
    * Available values: "none", "404-page", "single-page-application".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#not_found_handling WorkersScript#not_found_handling}
    */
    readonly notFoundHandling?: string;
    /**
    * When true, requests will always invoke the Worker script. Otherwise, attempt to serve an asset matching the request, falling back to the Worker script.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#run_worker_first WorkersScript#run_worker_first}
    */
    readonly runWorkerFirst?: boolean | cdktf.IResolvable;
    /**
    * When true and the incoming request matches an asset, that will be served instead of invoking the Worker script. When false, requests will always invoke the Worker script.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#serve_directly WorkersScript#serve_directly}
    */
    readonly serveDirectly?: boolean | cdktf.IResolvable;
}
export declare function workersScriptAssetsConfigToTerraform(struct?: WorkersScriptAssetsConfig | cdktf.IResolvable): any;
export declare function workersScriptAssetsConfigToHclTerraform(struct?: WorkersScriptAssetsConfig | cdktf.IResolvable): any;
export declare class WorkersScriptAssetsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptAssetsConfig | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptAssetsConfig | cdktf.IResolvable | undefined);
    private _headers?;
    get headers(): string;
    set headers(value: string);
    resetHeaders(): void;
    get headersInput(): string | undefined;
    private _redirects?;
    get redirects(): string;
    set redirects(value: string);
    resetRedirects(): void;
    get redirectsInput(): string | undefined;
    private _htmlHandling?;
    get htmlHandling(): string;
    set htmlHandling(value: string);
    resetHtmlHandling(): void;
    get htmlHandlingInput(): string | undefined;
    private _notFoundHandling?;
    get notFoundHandling(): string;
    set notFoundHandling(value: string);
    resetNotFoundHandling(): void;
    get notFoundHandlingInput(): string | undefined;
    private _runWorkerFirst?;
    get runWorkerFirst(): boolean | cdktf.IResolvable;
    set runWorkerFirst(value: boolean | cdktf.IResolvable);
    resetRunWorkerFirst(): void;
    get runWorkerFirstInput(): boolean | cdktf.IResolvable | undefined;
    private _serveDirectly?;
    get serveDirectly(): boolean | cdktf.IResolvable;
    set serveDirectly(value: boolean | cdktf.IResolvable);
    resetServeDirectly(): void;
    get serveDirectlyInput(): boolean | cdktf.IResolvable | undefined;
}
export interface WorkersScriptAssets {
    /**
    * Configuration for assets within a Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#config WorkersScript#config}
    */
    readonly config?: WorkersScriptAssetsConfig;
    /**
    * Token provided upon successful upload of all files from a registered manifest.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#jwt WorkersScript#jwt}
    */
    readonly jwt?: string;
}
export declare function workersScriptAssetsToTerraform(struct?: WorkersScriptAssets | cdktf.IResolvable): any;
export declare function workersScriptAssetsToHclTerraform(struct?: WorkersScriptAssets | cdktf.IResolvable): any;
export declare class WorkersScriptAssetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptAssets | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptAssets | cdktf.IResolvable | undefined);
    private _config;
    get config(): WorkersScriptAssetsConfigOutputReference;
    putConfig(value: WorkersScriptAssetsConfig): void;
    resetConfig(): void;
    get configInput(): cdktf.IResolvable | WorkersScriptAssetsConfig | undefined;
    private _jwt?;
    get jwt(): string;
    set jwt(value: string);
    resetJwt(): void;
    get jwtInput(): string | undefined;
}
export interface WorkersScriptBindingsOutboundWorker {
    /**
    * Environment of the outbound worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#environment WorkersScript#environment}
    */
    readonly environment?: string;
    /**
    * Name of the outbound worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#service WorkersScript#service}
    */
    readonly service?: string;
}
export declare function workersScriptBindingsOutboundWorkerToTerraform(struct?: WorkersScriptBindingsOutboundWorker | cdktf.IResolvable): any;
export declare function workersScriptBindingsOutboundWorkerToHclTerraform(struct?: WorkersScriptBindingsOutboundWorker | cdktf.IResolvable): any;
export declare class WorkersScriptBindingsOutboundWorkerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptBindingsOutboundWorker | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptBindingsOutboundWorker | cdktf.IResolvable | undefined);
    private _environment?;
    get environment(): string;
    set environment(value: string);
    resetEnvironment(): void;
    get environmentInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
}
export interface WorkersScriptBindingsOutbound {
    /**
    * Pass information from the Dispatch Worker to the Outbound Worker through the parameters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#params WorkersScript#params}
    */
    readonly params?: string[];
    /**
    * Outbound worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#worker WorkersScript#worker}
    */
    readonly worker?: WorkersScriptBindingsOutboundWorker;
}
export declare function workersScriptBindingsOutboundToTerraform(struct?: WorkersScriptBindingsOutbound | cdktf.IResolvable): any;
export declare function workersScriptBindingsOutboundToHclTerraform(struct?: WorkersScriptBindingsOutbound | cdktf.IResolvable): any;
export declare class WorkersScriptBindingsOutboundOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptBindingsOutbound | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptBindingsOutbound | cdktf.IResolvable | undefined);
    private _params?;
    get params(): string[];
    set params(value: string[]);
    resetParams(): void;
    get paramsInput(): string[] | undefined;
    private _worker;
    get worker(): WorkersScriptBindingsOutboundWorkerOutputReference;
    putWorker(value: WorkersScriptBindingsOutboundWorker): void;
    resetWorker(): void;
    get workerInput(): cdktf.IResolvable | WorkersScriptBindingsOutboundWorker | undefined;
}
export interface WorkersScriptBindings {
    /**
    * Algorithm-specific key parameters. [Learn more](https://developer.mozilla.org/en-US/docs/Web/API/SubtleCrypto/importKey#algorithm).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#algorithm WorkersScript#algorithm}
    */
    readonly algorithm?: string;
    /**
    * R2 bucket to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#bucket_name WorkersScript#bucket_name}
    */
    readonly bucketName?: string;
    /**
    * Identifier of the certificate to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#certificate_id WorkersScript#certificate_id}
    */
    readonly certificateId?: string;
    /**
    * The exported class name of the Durable Object.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#class_name WorkersScript#class_name}
    */
    readonly className?: string;
    /**
    * The name of the dataset to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#dataset WorkersScript#dataset}
    */
    readonly dataset?: string;
    /**
    * The environment of the script_name to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#environment WorkersScript#environment}
    */
    readonly environment?: string;
    /**
    * Data format of the key. [Learn more](https://developer.mozilla.org/en-US/docs/Web/API/SubtleCrypto/importKey#format).
    * Available values: "raw", "pkcs8", "spki", "jwk".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#format WorkersScript#format}
    */
    readonly format?: string;
    /**
    * Identifier of the D1 database to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#id WorkersScript#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the Vectorize index to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#index_name WorkersScript#index_name}
    */
    readonly indexName?: string;
    /**
    * JSON data to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#json WorkersScript#json}
    */
    readonly json?: string;
    /**
    * Base64-encoded key data. Required if `format` is "raw", "pkcs8", or "spki".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#key_base64 WorkersScript#key_base64}
    */
    readonly keyBase64?: string;
    /**
    * Key data in [JSON Web Key](https://developer.mozilla.org/en-US/docs/Web/API/SubtleCrypto/importKey#json_web_key) format. Required if `format` is "jwk".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#key_jwk WorkersScript#key_jwk}
    */
    readonly keyJwk?: string;
    /**
    * A JavaScript variable name for the binding.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
    /**
    * Namespace to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#namespace WorkersScript#namespace}
    */
    readonly namespace?: string;
    /**
    * Namespace identifier tag.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#namespace_id WorkersScript#namespace_id}
    */
    readonly namespaceId?: string;
    /**
    * Outbound worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#outbound WorkersScript#outbound}
    */
    readonly outbound?: WorkersScriptBindingsOutbound;
    /**
    * Name of the Pipeline to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#pipeline WorkersScript#pipeline}
    */
    readonly pipeline?: string;
    /**
    * Name of the Queue to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#queue_name WorkersScript#queue_name}
    */
    readonly queueName?: string;
    /**
    * The script where the Durable Object is defined, if it is external to this Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#script_name WorkersScript#script_name}
    */
    readonly scriptName?: string;
    /**
    * Name of the secret in the store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#secret_name WorkersScript#secret_name}
    */
    readonly secretName?: string;
    /**
    * Name of Worker to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#service WorkersScript#service}
    */
    readonly service?: string;
    /**
    * ID of the store containing the secret.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#store_id WorkersScript#store_id}
    */
    readonly storeId?: string;
    /**
    * The text value to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#text WorkersScript#text}
    */
    readonly text?: string;
    /**
    * The kind of resource that the binding provides.
    * Available values: "ai", "analytics_engine", "assets", "browser", "d1", "dispatch_namespace", "durable_object_namespace", "hyperdrive", "json", "kv_namespace", "mtls_certificate", "plain_text", "pipelines", "queue", "r2_bucket", "secret_text", "service", "tail_consumer", "vectorize", "version_metadata", "secrets_store_secret", "secret_key".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#type WorkersScript#type}
    */
    readonly type: string;
    /**
    * Allowed operations with the key. [Learn more](https://developer.mozilla.org/en-US/docs/Web/API/SubtleCrypto/importKey#keyUsages).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#usages WorkersScript#usages}
    */
    readonly usages?: string[];
    /**
    * Name of the Workflow to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#workflow_name WorkersScript#workflow_name}
    */
    readonly workflowName?: string;
}
export declare function workersScriptBindingsToTerraform(struct?: WorkersScriptBindings | cdktf.IResolvable): any;
export declare function workersScriptBindingsToHclTerraform(struct?: WorkersScriptBindings | cdktf.IResolvable): any;
export declare class WorkersScriptBindingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptBindings | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptBindings | cdktf.IResolvable | undefined);
    private _algorithm?;
    get algorithm(): string;
    set algorithm(value: string);
    resetAlgorithm(): void;
    get algorithmInput(): string | undefined;
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    resetBucketName(): void;
    get bucketNameInput(): string | undefined;
    private _certificateId?;
    get certificateId(): string;
    set certificateId(value: string);
    resetCertificateId(): void;
    get certificateIdInput(): string | undefined;
    private _className?;
    get className(): string;
    set className(value: string);
    resetClassName(): void;
    get classNameInput(): string | undefined;
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    resetDataset(): void;
    get datasetInput(): string | undefined;
    private _environment?;
    get environment(): string;
    set environment(value: string);
    resetEnvironment(): void;
    get environmentInput(): string | undefined;
    private _format?;
    get format(): string;
    set format(value: string);
    resetFormat(): void;
    get formatInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _indexName?;
    get indexName(): string;
    set indexName(value: string);
    resetIndexName(): void;
    get indexNameInput(): string | undefined;
    private _json?;
    get json(): string;
    set json(value: string);
    resetJson(): void;
    get jsonInput(): string | undefined;
    private _keyBase64?;
    get keyBase64(): string;
    set keyBase64(value: string);
    resetKeyBase64(): void;
    get keyBase64Input(): string | undefined;
    private _keyJwk?;
    get keyJwk(): string;
    set keyJwk(value: string);
    resetKeyJwk(): void;
    get keyJwkInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _namespaceId?;
    get namespaceId(): string;
    set namespaceId(value: string);
    resetNamespaceId(): void;
    get namespaceIdInput(): string | undefined;
    private _outbound;
    get outbound(): WorkersScriptBindingsOutboundOutputReference;
    putOutbound(value: WorkersScriptBindingsOutbound): void;
    resetOutbound(): void;
    get outboundInput(): cdktf.IResolvable | WorkersScriptBindingsOutbound | undefined;
    private _pipeline?;
    get pipeline(): string;
    set pipeline(value: string);
    resetPipeline(): void;
    get pipelineInput(): string | undefined;
    private _queueName?;
    get queueName(): string;
    set queueName(value: string);
    resetQueueName(): void;
    get queueNameInput(): string | undefined;
    private _scriptName?;
    get scriptName(): string;
    set scriptName(value: string);
    resetScriptName(): void;
    get scriptNameInput(): string | undefined;
    private _secretName?;
    get secretName(): string;
    set secretName(value: string);
    resetSecretName(): void;
    get secretNameInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _storeId?;
    get storeId(): string;
    set storeId(value: string);
    resetStoreId(): void;
    get storeIdInput(): string | undefined;
    private _text?;
    get text(): string;
    set text(value: string);
    resetText(): void;
    get textInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _usages?;
    get usages(): string[];
    set usages(value: string[]);
    resetUsages(): void;
    get usagesInput(): string[] | undefined;
    private _workflowName?;
    get workflowName(): string;
    set workflowName(value: string);
    resetWorkflowName(): void;
    get workflowNameInput(): string | undefined;
}
export declare class WorkersScriptBindingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptBindings[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptBindingsOutputReference;
}
export interface WorkersScriptMigrationsRenamedClasses {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#from WorkersScript#from}
    */
    readonly from?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#to WorkersScript#to}
    */
    readonly to?: string;
}
export declare function workersScriptMigrationsRenamedClassesToTerraform(struct?: WorkersScriptMigrationsRenamedClasses | cdktf.IResolvable): any;
export declare function workersScriptMigrationsRenamedClassesToHclTerraform(struct?: WorkersScriptMigrationsRenamedClasses | cdktf.IResolvable): any;
export declare class WorkersScriptMigrationsRenamedClassesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptMigrationsRenamedClasses | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptMigrationsRenamedClasses | cdktf.IResolvable | undefined);
    private _from?;
    get from(): string;
    set from(value: string);
    resetFrom(): void;
    get fromInput(): string | undefined;
    private _to?;
    get to(): string;
    set to(value: string);
    resetTo(): void;
    get toInput(): string | undefined;
}
export declare class WorkersScriptMigrationsRenamedClassesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptMigrationsRenamedClasses[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptMigrationsRenamedClassesOutputReference;
}
export interface WorkersScriptMigrationsStepsRenamedClasses {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#from WorkersScript#from}
    */
    readonly from?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#to WorkersScript#to}
    */
    readonly to?: string;
}
export declare function workersScriptMigrationsStepsRenamedClassesToTerraform(struct?: WorkersScriptMigrationsStepsRenamedClasses | cdktf.IResolvable): any;
export declare function workersScriptMigrationsStepsRenamedClassesToHclTerraform(struct?: WorkersScriptMigrationsStepsRenamedClasses | cdktf.IResolvable): any;
export declare class WorkersScriptMigrationsStepsRenamedClassesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptMigrationsStepsRenamedClasses | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptMigrationsStepsRenamedClasses | cdktf.IResolvable | undefined);
    private _from?;
    get from(): string;
    set from(value: string);
    resetFrom(): void;
    get fromInput(): string | undefined;
    private _to?;
    get to(): string;
    set to(value: string);
    resetTo(): void;
    get toInput(): string | undefined;
}
export declare class WorkersScriptMigrationsStepsRenamedClassesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptMigrationsStepsRenamedClasses[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptMigrationsStepsRenamedClassesOutputReference;
}
export interface WorkersScriptMigrationsStepsTransferredClasses {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#from WorkersScript#from}
    */
    readonly from?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#from_script WorkersScript#from_script}
    */
    readonly fromScript?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#to WorkersScript#to}
    */
    readonly to?: string;
}
export declare function workersScriptMigrationsStepsTransferredClassesToTerraform(struct?: WorkersScriptMigrationsStepsTransferredClasses | cdktf.IResolvable): any;
export declare function workersScriptMigrationsStepsTransferredClassesToHclTerraform(struct?: WorkersScriptMigrationsStepsTransferredClasses | cdktf.IResolvable): any;
export declare class WorkersScriptMigrationsStepsTransferredClassesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptMigrationsStepsTransferredClasses | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptMigrationsStepsTransferredClasses | cdktf.IResolvable | undefined);
    private _from?;
    get from(): string;
    set from(value: string);
    resetFrom(): void;
    get fromInput(): string | undefined;
    private _fromScript?;
    get fromScript(): string;
    set fromScript(value: string);
    resetFromScript(): void;
    get fromScriptInput(): string | undefined;
    private _to?;
    get to(): string;
    set to(value: string);
    resetTo(): void;
    get toInput(): string | undefined;
}
export declare class WorkersScriptMigrationsStepsTransferredClassesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptMigrationsStepsTransferredClasses[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptMigrationsStepsTransferredClassesOutputReference;
}
export interface WorkersScriptMigrationsSteps {
    /**
    * A list of classes to delete Durable Object namespaces from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#deleted_classes WorkersScript#deleted_classes}
    */
    readonly deletedClasses?: string[];
    /**
    * A list of classes to create Durable Object namespaces from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#new_classes WorkersScript#new_classes}
    */
    readonly newClasses?: string[];
    /**
    * A list of classes to create Durable Object namespaces with SQLite from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#new_sqlite_classes WorkersScript#new_sqlite_classes}
    */
    readonly newSqliteClasses?: string[];
    /**
    * A list of classes with Durable Object namespaces that were renamed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#renamed_classes WorkersScript#renamed_classes}
    */
    readonly renamedClasses?: WorkersScriptMigrationsStepsRenamedClasses[] | cdktf.IResolvable;
    /**
    * A list of transfers for Durable Object namespaces from a different Worker and class to a class defined in this Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#transferred_classes WorkersScript#transferred_classes}
    */
    readonly transferredClasses?: WorkersScriptMigrationsStepsTransferredClasses[] | cdktf.IResolvable;
}
export declare function workersScriptMigrationsStepsToTerraform(struct?: WorkersScriptMigrationsSteps | cdktf.IResolvable): any;
export declare function workersScriptMigrationsStepsToHclTerraform(struct?: WorkersScriptMigrationsSteps | cdktf.IResolvable): any;
export declare class WorkersScriptMigrationsStepsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptMigrationsSteps | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptMigrationsSteps | cdktf.IResolvable | undefined);
    private _deletedClasses?;
    get deletedClasses(): string[];
    set deletedClasses(value: string[]);
    resetDeletedClasses(): void;
    get deletedClassesInput(): string[] | undefined;
    private _newClasses?;
    get newClasses(): string[];
    set newClasses(value: string[]);
    resetNewClasses(): void;
    get newClassesInput(): string[] | undefined;
    private _newSqliteClasses?;
    get newSqliteClasses(): string[];
    set newSqliteClasses(value: string[]);
    resetNewSqliteClasses(): void;
    get newSqliteClassesInput(): string[] | undefined;
    private _renamedClasses;
    get renamedClasses(): WorkersScriptMigrationsStepsRenamedClassesList;
    putRenamedClasses(value: WorkersScriptMigrationsStepsRenamedClasses[] | cdktf.IResolvable): void;
    resetRenamedClasses(): void;
    get renamedClassesInput(): cdktf.IResolvable | WorkersScriptMigrationsStepsRenamedClasses[] | undefined;
    private _transferredClasses;
    get transferredClasses(): WorkersScriptMigrationsStepsTransferredClassesList;
    putTransferredClasses(value: WorkersScriptMigrationsStepsTransferredClasses[] | cdktf.IResolvable): void;
    resetTransferredClasses(): void;
    get transferredClassesInput(): cdktf.IResolvable | WorkersScriptMigrationsStepsTransferredClasses[] | undefined;
}
export declare class WorkersScriptMigrationsStepsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptMigrationsSteps[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptMigrationsStepsOutputReference;
}
export interface WorkersScriptMigrationsTransferredClasses {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#from WorkersScript#from}
    */
    readonly from?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#from_script WorkersScript#from_script}
    */
    readonly fromScript?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#to WorkersScript#to}
    */
    readonly to?: string;
}
export declare function workersScriptMigrationsTransferredClassesToTerraform(struct?: WorkersScriptMigrationsTransferredClasses | cdktf.IResolvable): any;
export declare function workersScriptMigrationsTransferredClassesToHclTerraform(struct?: WorkersScriptMigrationsTransferredClasses | cdktf.IResolvable): any;
export declare class WorkersScriptMigrationsTransferredClassesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptMigrationsTransferredClasses | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptMigrationsTransferredClasses | cdktf.IResolvable | undefined);
    private _from?;
    get from(): string;
    set from(value: string);
    resetFrom(): void;
    get fromInput(): string | undefined;
    private _fromScript?;
    get fromScript(): string;
    set fromScript(value: string);
    resetFromScript(): void;
    get fromScriptInput(): string | undefined;
    private _to?;
    get to(): string;
    set to(value: string);
    resetTo(): void;
    get toInput(): string | undefined;
}
export declare class WorkersScriptMigrationsTransferredClassesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptMigrationsTransferredClasses[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptMigrationsTransferredClassesOutputReference;
}
export interface WorkersScriptMigrations {
    /**
    * A list of classes to delete Durable Object namespaces from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#deleted_classes WorkersScript#deleted_classes}
    */
    readonly deletedClasses?: string[];
    /**
    * A list of classes to create Durable Object namespaces from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#new_classes WorkersScript#new_classes}
    */
    readonly newClasses?: string[];
    /**
    * A list of classes to create Durable Object namespaces with SQLite from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#new_sqlite_classes WorkersScript#new_sqlite_classes}
    */
    readonly newSqliteClasses?: string[];
    /**
    * Tag to set as the latest migration tag.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#new_tag WorkersScript#new_tag}
    */
    readonly newTag?: string;
    /**
    * Tag used to verify against the latest migration tag for this Worker. If they don't match, the upload is rejected.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#old_tag WorkersScript#old_tag}
    */
    readonly oldTag?: string;
    /**
    * A list of classes with Durable Object namespaces that were renamed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#renamed_classes WorkersScript#renamed_classes}
    */
    readonly renamedClasses?: WorkersScriptMigrationsRenamedClasses[] | cdktf.IResolvable;
    /**
    * Migrations to apply in order.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#steps WorkersScript#steps}
    */
    readonly steps?: WorkersScriptMigrationsSteps[] | cdktf.IResolvable;
    /**
    * A list of transfers for Durable Object namespaces from a different Worker and class to a class defined in this Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#transferred_classes WorkersScript#transferred_classes}
    */
    readonly transferredClasses?: WorkersScriptMigrationsTransferredClasses[] | cdktf.IResolvable;
}
export declare function workersScriptMigrationsToTerraform(struct?: WorkersScriptMigrations | cdktf.IResolvable): any;
export declare function workersScriptMigrationsToHclTerraform(struct?: WorkersScriptMigrations | cdktf.IResolvable): any;
export declare class WorkersScriptMigrationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptMigrations | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptMigrations | cdktf.IResolvable | undefined);
    private _deletedClasses?;
    get deletedClasses(): string[];
    set deletedClasses(value: string[]);
    resetDeletedClasses(): void;
    get deletedClassesInput(): string[] | undefined;
    private _newClasses?;
    get newClasses(): string[];
    set newClasses(value: string[]);
    resetNewClasses(): void;
    get newClassesInput(): string[] | undefined;
    private _newSqliteClasses?;
    get newSqliteClasses(): string[];
    set newSqliteClasses(value: string[]);
    resetNewSqliteClasses(): void;
    get newSqliteClassesInput(): string[] | undefined;
    private _newTag?;
    get newTag(): string;
    set newTag(value: string);
    resetNewTag(): void;
    get newTagInput(): string | undefined;
    private _oldTag?;
    get oldTag(): string;
    set oldTag(value: string);
    resetOldTag(): void;
    get oldTagInput(): string | undefined;
    private _renamedClasses;
    get renamedClasses(): WorkersScriptMigrationsRenamedClassesList;
    putRenamedClasses(value: WorkersScriptMigrationsRenamedClasses[] | cdktf.IResolvable): void;
    resetRenamedClasses(): void;
    get renamedClassesInput(): cdktf.IResolvable | WorkersScriptMigrationsRenamedClasses[] | undefined;
    private _steps;
    get steps(): WorkersScriptMigrationsStepsList;
    putSteps(value: WorkersScriptMigrationsSteps[] | cdktf.IResolvable): void;
    resetSteps(): void;
    get stepsInput(): cdktf.IResolvable | WorkersScriptMigrationsSteps[] | undefined;
    private _transferredClasses;
    get transferredClasses(): WorkersScriptMigrationsTransferredClassesList;
    putTransferredClasses(value: WorkersScriptMigrationsTransferredClasses[] | cdktf.IResolvable): void;
    resetTransferredClasses(): void;
    get transferredClassesInput(): cdktf.IResolvable | WorkersScriptMigrationsTransferredClasses[] | undefined;
}
export interface WorkersScriptObservabilityLogs {
    /**
    * Whether logs are enabled for the Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#enabled WorkersScript#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * The sampling rate for logs. From 0 to 1 (1 = 100%, 0.1 = 10%). Default is 1.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#head_sampling_rate WorkersScript#head_sampling_rate}
    */
    readonly headSamplingRate?: number;
    /**
    * Whether [invocation logs](https://developers.cloudflare.com/workers/observability/logs/workers-logs/#invocation-logs) are enabled for the Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#invocation_logs WorkersScript#invocation_logs}
    */
    readonly invocationLogs: boolean | cdktf.IResolvable;
}
export declare function workersScriptObservabilityLogsToTerraform(struct?: WorkersScriptObservabilityLogs | cdktf.IResolvable): any;
export declare function workersScriptObservabilityLogsToHclTerraform(struct?: WorkersScriptObservabilityLogs | cdktf.IResolvable): any;
export declare class WorkersScriptObservabilityLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptObservabilityLogs | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptObservabilityLogs | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _headSamplingRate?;
    get headSamplingRate(): number;
    set headSamplingRate(value: number);
    resetHeadSamplingRate(): void;
    get headSamplingRateInput(): number | undefined;
    private _invocationLogs?;
    get invocationLogs(): boolean | cdktf.IResolvable;
    set invocationLogs(value: boolean | cdktf.IResolvable);
    get invocationLogsInput(): boolean | cdktf.IResolvable | undefined;
}
export interface WorkersScriptObservability {
    /**
    * Whether observability is enabled for the Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#enabled WorkersScript#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * The sampling rate for incoming requests. From 0 to 1 (1 = 100%, 0.1 = 10%). Default is 1.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#head_sampling_rate WorkersScript#head_sampling_rate}
    */
    readonly headSamplingRate?: number;
    /**
    * Log settings for the Worker.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#logs WorkersScript#logs}
    */
    readonly logs?: WorkersScriptObservabilityLogs;
}
export declare function workersScriptObservabilityToTerraform(struct?: WorkersScriptObservability | cdktf.IResolvable): any;
export declare function workersScriptObservabilityToHclTerraform(struct?: WorkersScriptObservability | cdktf.IResolvable): any;
export declare class WorkersScriptObservabilityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptObservability | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptObservability | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _headSamplingRate?;
    get headSamplingRate(): number;
    set headSamplingRate(value: number);
    resetHeadSamplingRate(): void;
    get headSamplingRateInput(): number | undefined;
    private _logs;
    get logs(): WorkersScriptObservabilityLogsOutputReference;
    putLogs(value: WorkersScriptObservabilityLogs): void;
    resetLogs(): void;
    get logsInput(): cdktf.IResolvable | WorkersScriptObservabilityLogs | undefined;
}
export interface WorkersScriptPlacement {
    /**
    * Enables [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    * Available values: "smart".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#mode WorkersScript#mode}
    */
    readonly mode?: string;
}
export declare function workersScriptPlacementToTerraform(struct?: WorkersScriptPlacement | cdktf.IResolvable): any;
export declare function workersScriptPlacementToHclTerraform(struct?: WorkersScriptPlacement | cdktf.IResolvable): any;
export declare class WorkersScriptPlacementOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkersScriptPlacement | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptPlacement | cdktf.IResolvable | undefined);
    get lastAnalyzedAt(): string;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    get status(): string;
}
export interface WorkersScriptTailConsumers {
    /**
    * Optional environment if the Worker utilizes one.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#environment WorkersScript#environment}
    */
    readonly environment?: string;
    /**
    * Optional dispatch namespace the script belongs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#namespace WorkersScript#namespace}
    */
    readonly namespace?: string;
    /**
    * Name of Worker that is to be the consumer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#service WorkersScript#service}
    */
    readonly service: string;
}
export declare function workersScriptTailConsumersToTerraform(struct?: WorkersScriptTailConsumers | cdktf.IResolvable): any;
export declare function workersScriptTailConsumersToHclTerraform(struct?: WorkersScriptTailConsumers | cdktf.IResolvable): any;
export declare class WorkersScriptTailConsumersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptTailConsumers | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptTailConsumers | cdktf.IResolvable | undefined);
    private _environment?;
    get environment(): string;
    set environment(value: string);
    resetEnvironment(): void;
    get environmentInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
}
export declare class WorkersScriptTailConsumersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptTailConsumers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptTailConsumersOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script cloudflare_workers_script}
*/
export declare class WorkersScript extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_workers_script";
    /**
    * Generates CDKTF code for importing a WorkersScript resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WorkersScript to import
    * @param importFromId The id of the existing WorkersScript that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WorkersScript to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/workers_script cloudflare_workers_script} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WorkersScriptConfig
    */
    constructor(scope: Construct, id: string, config: WorkersScriptConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _assets;
    get assets(): WorkersScriptAssetsOutputReference;
    putAssets(value: WorkersScriptAssets): void;
    resetAssets(): void;
    get assetsInput(): cdktf.IResolvable | WorkersScriptAssets | undefined;
    private _bindings;
    get bindings(): WorkersScriptBindingsList;
    putBindings(value: WorkersScriptBindings[] | cdktf.IResolvable): void;
    resetBindings(): void;
    get bindingsInput(): cdktf.IResolvable | WorkersScriptBindings[] | undefined;
    private _bodyPart?;
    get bodyPart(): string;
    set bodyPart(value: string);
    resetBodyPart(): void;
    get bodyPartInput(): string | undefined;
    private _compatibilityDate?;
    get compatibilityDate(): string;
    set compatibilityDate(value: string);
    resetCompatibilityDate(): void;
    get compatibilityDateInput(): string | undefined;
    private _compatibilityFlags?;
    get compatibilityFlags(): string[];
    set compatibilityFlags(value: string[]);
    resetCompatibilityFlags(): void;
    get compatibilityFlagsInput(): string[] | undefined;
    private _content?;
    get content(): string;
    set content(value: string);
    get contentInput(): string | undefined;
    get createdOn(): string;
    get etag(): string;
    get hasAssets(): cdktf.IResolvable;
    get hasModules(): cdktf.IResolvable;
    get id(): string;
    private _keepAssets?;
    get keepAssets(): boolean | cdktf.IResolvable;
    set keepAssets(value: boolean | cdktf.IResolvable);
    resetKeepAssets(): void;
    get keepAssetsInput(): boolean | cdktf.IResolvable | undefined;
    private _keepBindings?;
    get keepBindings(): string[];
    set keepBindings(value: string[]);
    resetKeepBindings(): void;
    get keepBindingsInput(): string[] | undefined;
    private _logpush?;
    get logpush(): boolean | cdktf.IResolvable;
    set logpush(value: boolean | cdktf.IResolvable);
    resetLogpush(): void;
    get logpushInput(): boolean | cdktf.IResolvable | undefined;
    private _mainModule?;
    get mainModule(): string;
    set mainModule(value: string);
    resetMainModule(): void;
    get mainModuleInput(): string | undefined;
    private _migrations;
    get migrations(): WorkersScriptMigrationsOutputReference;
    putMigrations(value: WorkersScriptMigrations): void;
    resetMigrations(): void;
    get migrationsInput(): cdktf.IResolvable | WorkersScriptMigrations | undefined;
    get modifiedOn(): string;
    private _observability;
    get observability(): WorkersScriptObservabilityOutputReference;
    putObservability(value: WorkersScriptObservability): void;
    resetObservability(): void;
    get observabilityInput(): cdktf.IResolvable | WorkersScriptObservability | undefined;
    private _placement;
    get placement(): WorkersScriptPlacementOutputReference;
    putPlacement(value: WorkersScriptPlacement): void;
    resetPlacement(): void;
    get placementInput(): cdktf.IResolvable | WorkersScriptPlacement | undefined;
    private _scriptName?;
    get scriptName(): string;
    set scriptName(value: string);
    get scriptNameInput(): string | undefined;
    get startupTimeMs(): number;
    private _tailConsumers;
    get tailConsumers(): WorkersScriptTailConsumersList;
    putTailConsumers(value: WorkersScriptTailConsumers[] | cdktf.IResolvable): void;
    resetTailConsumers(): void;
    get tailConsumersInput(): cdktf.IResolvable | WorkersScriptTailConsumers[] | undefined;
    private _usageModel?;
    get usageModel(): string;
    set usageModel(value: string);
    resetUsageModel(): void;
    get usageModelInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
