/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustDeviceSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings#account_id ZeroTrustDeviceSettings#account_id}
    */
    readonly accountId: string;
    /**
    * Sets the time limit, in seconds, that a user can use an override code to bypass WARP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings#disable_for_time ZeroTrustDeviceSettings#disable_for_time}
    */
    readonly disableForTime?: number;
    /**
    * Enable gateway proxy filtering on TCP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings#gateway_proxy_enabled ZeroTrustDeviceSettings#gateway_proxy_enabled}
    */
    readonly gatewayProxyEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable gateway proxy filtering on UDP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings#gateway_udp_proxy_enabled ZeroTrustDeviceSettings#gateway_udp_proxy_enabled}
    */
    readonly gatewayUdpProxyEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable installation of cloudflare managed root certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings#root_certificate_installation_enabled ZeroTrustDeviceSettings#root_certificate_installation_enabled}
    */
    readonly rootCertificateInstallationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable using CGNAT virtual IPv4.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings#use_zt_virtual_ip ZeroTrustDeviceSettings#use_zt_virtual_ip}
    */
    readonly useZtVirtualIp?: boolean | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings cloudflare_zero_trust_device_settings}
*/
export declare class ZeroTrustDeviceSettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_device_settings";
    /**
    * Generates CDKTF code for importing a ZeroTrustDeviceSettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustDeviceSettings to import
    * @param importFromId The id of the existing ZeroTrustDeviceSettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustDeviceSettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_device_settings cloudflare_zero_trust_device_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustDeviceSettingsConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustDeviceSettingsConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _disableForTime?;
    get disableForTime(): number;
    set disableForTime(value: number);
    resetDisableForTime(): void;
    get disableForTimeInput(): number | undefined;
    private _gatewayProxyEnabled?;
    get gatewayProxyEnabled(): boolean | cdktf.IResolvable;
    set gatewayProxyEnabled(value: boolean | cdktf.IResolvable);
    resetGatewayProxyEnabled(): void;
    get gatewayProxyEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _gatewayUdpProxyEnabled?;
    get gatewayUdpProxyEnabled(): boolean | cdktf.IResolvable;
    set gatewayUdpProxyEnabled(value: boolean | cdktf.IResolvable);
    resetGatewayUdpProxyEnabled(): void;
    get gatewayUdpProxyEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _rootCertificateInstallationEnabled?;
    get rootCertificateInstallationEnabled(): boolean | cdktf.IResolvable;
    set rootCertificateInstallationEnabled(value: boolean | cdktf.IResolvable);
    resetRootCertificateInstallationEnabled(): void;
    get rootCertificateInstallationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _useZtVirtualIp?;
    get useZtVirtualIp(): boolean | cdktf.IResolvable;
    set useZtVirtualIp(value: boolean | cdktf.IResolvable);
    resetUseZtVirtualIp(): void;
    get useZtVirtualIpInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
