/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustDlpEntryConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#account_id ZeroTrustDlpEntry#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#enabled ZeroTrustDlpEntry#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#name ZeroTrustDlpEntry#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#pattern ZeroTrustDlpEntry#pattern}
    */
    readonly pattern: ZeroTrustDlpEntryPattern;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#profile_id ZeroTrustDlpEntry#profile_id}
    */
    readonly profileId: string;
    /**
    * Available values: "custom", "predefined", "integration".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#type ZeroTrustDlpEntry#type}
    */
    readonly type?: string;
}
export interface ZeroTrustDlpEntryConfidence {
}
export declare function zeroTrustDlpEntryConfidenceToTerraform(struct?: ZeroTrustDlpEntryConfidence): any;
export declare function zeroTrustDlpEntryConfidenceToHclTerraform(struct?: ZeroTrustDlpEntryConfidence): any;
export declare class ZeroTrustDlpEntryConfidenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustDlpEntryConfidence | undefined;
    set internalValue(value: ZeroTrustDlpEntryConfidence | undefined);
    get aiContextAvailable(): cdktf.IResolvable;
    get available(): cdktf.IResolvable;
}
export interface ZeroTrustDlpEntryPattern {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#regex ZeroTrustDlpEntry#regex}
    */
    readonly regex: string;
    /**
    * Available values: "luhn".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#validation ZeroTrustDlpEntry#validation}
    */
    readonly validation?: string;
}
export declare function zeroTrustDlpEntryPatternToTerraform(struct?: ZeroTrustDlpEntryPattern | cdktf.IResolvable): any;
export declare function zeroTrustDlpEntryPatternToHclTerraform(struct?: ZeroTrustDlpEntryPattern | cdktf.IResolvable): any;
export declare class ZeroTrustDlpEntryPatternOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustDlpEntryPattern | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustDlpEntryPattern | cdktf.IResolvable | undefined);
    private _regex?;
    get regex(): string;
    set regex(value: string);
    get regexInput(): string | undefined;
    private _validation?;
    get validation(): string;
    set validation(value: string);
    resetValidation(): void;
    get validationInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry cloudflare_zero_trust_dlp_entry}
*/
export declare class ZeroTrustDlpEntry extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_dlp_entry";
    /**
    * Generates CDKTF code for importing a ZeroTrustDlpEntry resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustDlpEntry to import
    * @param importFromId The id of the existing ZeroTrustDlpEntry that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustDlpEntry to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_dlp_entry cloudflare_zero_trust_dlp_entry} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustDlpEntryConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustDlpEntryConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get caseSensitive(): cdktf.IResolvable;
    private _confidence;
    get confidence(): ZeroTrustDlpEntryConfidenceOutputReference;
    get createdAt(): string;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _pattern;
    get pattern(): ZeroTrustDlpEntryPatternOutputReference;
    putPattern(value: ZeroTrustDlpEntryPattern): void;
    get patternInput(): cdktf.IResolvable | ZeroTrustDlpEntryPattern | undefined;
    private _profileId?;
    get profileId(): string;
    set profileId(value: string);
    get profileIdInput(): string | undefined;
    get secret(): cdktf.IResolvable;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    get updatedAt(): string;
    get wordList(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
