/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustGatewayLoggingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#account_id ZeroTrustGatewayLogging#account_id}
    */
    readonly accountId: string;
    /**
    * Redact personally identifiable information from activity logging (PII fields are: source IP, user email, user ID, device ID, URL, referrer, user agent).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#redact_pii ZeroTrustGatewayLogging#redact_pii}
    */
    readonly redactPii?: boolean | cdktf.IResolvable;
    /**
    * Logging settings by rule type.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#settings_by_rule_type ZeroTrustGatewayLogging#settings_by_rule_type}
    */
    readonly settingsByRuleType?: ZeroTrustGatewayLoggingSettingsByRuleType;
}
export interface ZeroTrustGatewayLoggingSettingsByRuleTypeDns {
    /**
    * Log all requests to this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#log_all ZeroTrustGatewayLogging#log_all}
    */
    readonly logAll?: boolean | cdktf.IResolvable;
    /**
    * Log only blocking requests to this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#log_blocks ZeroTrustGatewayLogging#log_blocks}
    */
    readonly logBlocks?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeDnsToTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleTypeDns | cdktf.IResolvable): any;
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeDnsToHclTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleTypeDns | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayLoggingSettingsByRuleTypeDnsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayLoggingSettingsByRuleTypeDns | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayLoggingSettingsByRuleTypeDns | cdktf.IResolvable | undefined);
    private _logAll?;
    get logAll(): boolean | cdktf.IResolvable;
    set logAll(value: boolean | cdktf.IResolvable);
    resetLogAll(): void;
    get logAllInput(): boolean | cdktf.IResolvable | undefined;
    private _logBlocks?;
    get logBlocks(): boolean | cdktf.IResolvable;
    set logBlocks(value: boolean | cdktf.IResolvable);
    resetLogBlocks(): void;
    get logBlocksInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayLoggingSettingsByRuleTypeHttp {
    /**
    * Log all requests to this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#log_all ZeroTrustGatewayLogging#log_all}
    */
    readonly logAll?: boolean | cdktf.IResolvable;
    /**
    * Log only blocking requests to this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#log_blocks ZeroTrustGatewayLogging#log_blocks}
    */
    readonly logBlocks?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeHttpToTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleTypeHttp | cdktf.IResolvable): any;
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeHttpToHclTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleTypeHttp | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayLoggingSettingsByRuleTypeHttpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayLoggingSettingsByRuleTypeHttp | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayLoggingSettingsByRuleTypeHttp | cdktf.IResolvable | undefined);
    private _logAll?;
    get logAll(): boolean | cdktf.IResolvable;
    set logAll(value: boolean | cdktf.IResolvable);
    resetLogAll(): void;
    get logAllInput(): boolean | cdktf.IResolvable | undefined;
    private _logBlocks?;
    get logBlocks(): boolean | cdktf.IResolvable;
    set logBlocks(value: boolean | cdktf.IResolvable);
    resetLogBlocks(): void;
    get logBlocksInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayLoggingSettingsByRuleTypeL4 {
    /**
    * Log all requests to this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#log_all ZeroTrustGatewayLogging#log_all}
    */
    readonly logAll?: boolean | cdktf.IResolvable;
    /**
    * Log only blocking requests to this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#log_blocks ZeroTrustGatewayLogging#log_blocks}
    */
    readonly logBlocks?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeL4ToTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleTypeL4 | cdktf.IResolvable): any;
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeL4ToHclTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleTypeL4 | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayLoggingSettingsByRuleTypeL4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayLoggingSettingsByRuleTypeL4 | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayLoggingSettingsByRuleTypeL4 | cdktf.IResolvable | undefined);
    private _logAll?;
    get logAll(): boolean | cdktf.IResolvable;
    set logAll(value: boolean | cdktf.IResolvable);
    resetLogAll(): void;
    get logAllInput(): boolean | cdktf.IResolvable | undefined;
    private _logBlocks?;
    get logBlocks(): boolean | cdktf.IResolvable;
    set logBlocks(value: boolean | cdktf.IResolvable);
    resetLogBlocks(): void;
    get logBlocksInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayLoggingSettingsByRuleType {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#dns ZeroTrustGatewayLogging#dns}
    */
    readonly dns?: ZeroTrustGatewayLoggingSettingsByRuleTypeDns;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#http ZeroTrustGatewayLogging#http}
    */
    readonly http?: ZeroTrustGatewayLoggingSettingsByRuleTypeHttp;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#l4 ZeroTrustGatewayLogging#l4}
    */
    readonly l4?: ZeroTrustGatewayLoggingSettingsByRuleTypeL4;
}
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeToTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleType | cdktf.IResolvable): any;
export declare function zeroTrustGatewayLoggingSettingsByRuleTypeToHclTerraform(struct?: ZeroTrustGatewayLoggingSettingsByRuleType | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayLoggingSettingsByRuleTypeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayLoggingSettingsByRuleType | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayLoggingSettingsByRuleType | cdktf.IResolvable | undefined);
    private _dns;
    get dns(): ZeroTrustGatewayLoggingSettingsByRuleTypeDnsOutputReference;
    putDns(value: ZeroTrustGatewayLoggingSettingsByRuleTypeDns): void;
    resetDns(): void;
    get dnsInput(): cdktf.IResolvable | ZeroTrustGatewayLoggingSettingsByRuleTypeDns | undefined;
    private _http;
    get http(): ZeroTrustGatewayLoggingSettingsByRuleTypeHttpOutputReference;
    putHttp(value: ZeroTrustGatewayLoggingSettingsByRuleTypeHttp): void;
    resetHttp(): void;
    get httpInput(): cdktf.IResolvable | ZeroTrustGatewayLoggingSettingsByRuleTypeHttp | undefined;
    private _l4;
    get l4(): ZeroTrustGatewayLoggingSettingsByRuleTypeL4OutputReference;
    putL4(value: ZeroTrustGatewayLoggingSettingsByRuleTypeL4): void;
    resetL4(): void;
    get l4Input(): cdktf.IResolvable | ZeroTrustGatewayLoggingSettingsByRuleTypeL4 | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging cloudflare_zero_trust_gateway_logging}
*/
export declare class ZeroTrustGatewayLogging extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_gateway_logging";
    /**
    * Generates CDKTF code for importing a ZeroTrustGatewayLogging resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustGatewayLogging to import
    * @param importFromId The id of the existing ZeroTrustGatewayLogging that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustGatewayLogging to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_logging cloudflare_zero_trust_gateway_logging} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustGatewayLoggingConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustGatewayLoggingConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _redactPii?;
    get redactPii(): boolean | cdktf.IResolvable;
    set redactPii(value: boolean | cdktf.IResolvable);
    resetRedactPii(): void;
    get redactPiiInput(): boolean | cdktf.IResolvable | undefined;
    private _settingsByRuleType;
    get settingsByRuleType(): ZeroTrustGatewayLoggingSettingsByRuleTypeOutputReference;
    putSettingsByRuleType(value: ZeroTrustGatewayLoggingSettingsByRuleType): void;
    resetSettingsByRuleType(): void;
    get settingsByRuleTypeInput(): cdktf.IResolvable | ZeroTrustGatewayLoggingSettingsByRuleType | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
