/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustGatewayPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#account_id ZeroTrustGatewayPolicy#account_id}
    */
    readonly accountId: string;
    /**
    * The action to preform when the associated traffic, identity, and device posture expressions are either absent or evaluate to `true`.
    * Available values: "on", "off", "allow", "block", "scan", "noscan", "safesearch", "ytrestricted", "isolate", "noisolate", "override", "l4_override", "egress", "resolve", "quarantine", "redirect".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#action ZeroTrustGatewayPolicy#action}
    */
    readonly action: string;
    /**
    * The description of the rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#description ZeroTrustGatewayPolicy#description}
    */
    readonly description?: string;
    /**
    * The wirefilter expression used for device posture check matching.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#device_posture ZeroTrustGatewayPolicy#device_posture}
    */
    readonly devicePosture?: string;
    /**
    * True if the rule is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#enabled ZeroTrustGatewayPolicy#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * The expiration time stamp and default duration of a DNS policy. Takes
    * precedence over the policy's `schedule` configuration, if any.
    *
    * This does not apply to HTTP or network policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#expiration ZeroTrustGatewayPolicy#expiration}
    */
    readonly expiration?: ZeroTrustGatewayPolicyExpiration;
    /**
    * The protocol or layer to evaluate the traffic, identity, and device posture expressions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#filters ZeroTrustGatewayPolicy#filters}
    */
    readonly filters?: string[];
    /**
    * The wirefilter expression used for identity matching.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#identity ZeroTrustGatewayPolicy#identity}
    */
    readonly identity?: string;
    /**
    * The name of the rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#name ZeroTrustGatewayPolicy#name}
    */
    readonly name: string;
    /**
    * Precedence sets the order of your rules. Lower values indicate higher precedence. At each processing phase, applicable rules are evaluated in ascending order of this value. Refer to [Order of enforcement](http://developers.cloudflare.com/learning-paths/secure-internet-traffic/understand-policies/order-of-enforcement/#manage-precedence-with-terraform) docs on how to manage precedence via Terraform.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#precedence ZeroTrustGatewayPolicy#precedence}
    */
    readonly precedence?: number;
    /**
    * Additional settings that modify the rule's action.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#rule_settings ZeroTrustGatewayPolicy#rule_settings}
    */
    readonly ruleSettings?: ZeroTrustGatewayPolicyRuleSettings;
    /**
    * The schedule for activating DNS policies. This does not apply to HTTP or network policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#schedule ZeroTrustGatewayPolicy#schedule}
    */
    readonly schedule?: ZeroTrustGatewayPolicySchedule;
    /**
    * The wirefilter expression used for traffic matching.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#traffic ZeroTrustGatewayPolicy#traffic}
    */
    readonly traffic?: string;
}
export interface ZeroTrustGatewayPolicyExpiration {
    /**
    * The default duration a policy will be active in minutes. Must be set in order to use the `reset_expiration` endpoint on this rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#duration ZeroTrustGatewayPolicy#duration}
    */
    readonly duration?: number;
    /**
    * The time stamp at which the policy will expire and cease to be
    * applied.
    *
    * Must adhere to RFC 3339 and include a UTC offset. Non-zero
    * offsets are accepted but will be converted to the equivalent
    * value with offset zero (UTC+00:00) and will be returned as time
    * stamps with offset zero denoted by a trailing 'Z'.
    *
    * Policies with an expiration do not consider the timezone of
    * clients they are applied to, and expire "globally" at the point
    * given by their `expires_at` value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#expires_at ZeroTrustGatewayPolicy#expires_at}
    */
    readonly expiresAt: string;
}
export declare function zeroTrustGatewayPolicyExpirationToTerraform(struct?: ZeroTrustGatewayPolicyExpiration | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyExpirationToHclTerraform(struct?: ZeroTrustGatewayPolicyExpiration | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyExpirationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyExpiration | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyExpiration | cdktf.IResolvable | undefined);
    private _duration?;
    get duration(): number;
    set duration(value: number);
    resetDuration(): void;
    get durationInput(): number | undefined;
    get expired(): cdktf.IResolvable;
    private _expiresAt?;
    get expiresAt(): string;
    set expiresAt(value: string);
    get expiresAtInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsAuditSsh {
    /**
    * Enable to turn on SSH command logging.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#command_logging ZeroTrustGatewayPolicy#command_logging}
    */
    readonly commandLogging?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsAuditSshToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsAuditSsh | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsAuditSshToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsAuditSsh | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsAuditSshOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsAuditSsh | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsAuditSsh | cdktf.IResolvable | undefined);
    private _commandLogging?;
    get commandLogging(): boolean | cdktf.IResolvable;
    set commandLogging(value: boolean | cdktf.IResolvable);
    resetCommandLogging(): void;
    get commandLoggingInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls {
    /**
    * Configure whether copy is enabled or not. When set with "remote_only", copying isolated content from the remote browser to the user's local clipboard is disabled. When absent, copy is enabled. Only applies when `version == "v2"`.
    * Available values: "enabled", "disabled", "remote_only".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#copy ZeroTrustGatewayPolicy#copy}
    */
    readonly copy?: string;
    /**
    * Set to false to enable copy-pasting. Only applies when `version == "v1"`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#dcp ZeroTrustGatewayPolicy#dcp}
    */
    readonly dcp?: boolean | cdktf.IResolvable;
    /**
    * Set to false to enable downloading. Only applies when `version == "v1"`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#dd ZeroTrustGatewayPolicy#dd}
    */
    readonly dd?: boolean | cdktf.IResolvable;
    /**
    * Set to false to enable keyboard usage. Only applies when `version == "v1"`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#dk ZeroTrustGatewayPolicy#dk}
    */
    readonly dk?: boolean | cdktf.IResolvable;
    /**
    * Configure whether downloading enabled or not. When set with "remote_only", downloads are only available for viewing. Only applies when `version == "v2"`.
    * Available values: "enabled", "disabled", "remote_only".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#download ZeroTrustGatewayPolicy#download}
    */
    readonly download?: string;
    /**
    * Set to false to enable printing. Only applies when `version == "v1"`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#dp ZeroTrustGatewayPolicy#dp}
    */
    readonly dp?: boolean | cdktf.IResolvable;
    /**
    * Set to false to enable uploading. Only applies when `version == "v1"`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#du ZeroTrustGatewayPolicy#du}
    */
    readonly du?: boolean | cdktf.IResolvable;
    /**
    * Configure whether keyboard usage is enabled or not. When absent, keyboard usage is enabled. Only applies when `version == "v2"`.
    * Available values: "enabled", "disabled".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#keyboard ZeroTrustGatewayPolicy#keyboard}
    */
    readonly keyboard?: string;
    /**
    * Configure whether pasting is enabled or not. When set with "remote_only", pasting content from the user's local clipboard into isolated pages is disabled. When absent, paste is enabled. Only applies when `version == "v2"`.
    * Available values: "enabled", "disabled", "remote_only".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#paste ZeroTrustGatewayPolicy#paste}
    */
    readonly paste?: string;
    /**
    * Configure whether printing is enabled or not. When absent, printing is enabled. Only applies when `version == "v2"`.
    * Available values: "enabled", "disabled".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#printing ZeroTrustGatewayPolicy#printing}
    */
    readonly printing?: string;
    /**
    * Configure whether uploading is enabled or not. When absent, uploading is enabled. Only applies when `version == "v2"`.
    * Available values: "enabled", "disabled".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#upload ZeroTrustGatewayPolicy#upload}
    */
    readonly upload?: string;
    /**
    * Indicates which version of the browser isolation controls should apply.
    * Available values: "v1", "v2".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#version ZeroTrustGatewayPolicy#version}
    */
    readonly version?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsBisoAdminControlsToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsBisoAdminControlsToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsBisoAdminControlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | cdktf.IResolvable | undefined);
    private _copy?;
    get copy(): string;
    set copy(value: string);
    resetCopy(): void;
    get copyInput(): string | undefined;
    private _dcp?;
    get dcp(): boolean | cdktf.IResolvable;
    set dcp(value: boolean | cdktf.IResolvable);
    resetDcp(): void;
    get dcpInput(): boolean | cdktf.IResolvable | undefined;
    private _dd?;
    get dd(): boolean | cdktf.IResolvable;
    set dd(value: boolean | cdktf.IResolvable);
    resetDd(): void;
    get ddInput(): boolean | cdktf.IResolvable | undefined;
    private _dk?;
    get dk(): boolean | cdktf.IResolvable;
    set dk(value: boolean | cdktf.IResolvable);
    resetDk(): void;
    get dkInput(): boolean | cdktf.IResolvable | undefined;
    private _download?;
    get download(): string;
    set download(value: string);
    resetDownload(): void;
    get downloadInput(): string | undefined;
    private _dp?;
    get dp(): boolean | cdktf.IResolvable;
    set dp(value: boolean | cdktf.IResolvable);
    resetDp(): void;
    get dpInput(): boolean | cdktf.IResolvable | undefined;
    private _du?;
    get du(): boolean | cdktf.IResolvable;
    set du(value: boolean | cdktf.IResolvable);
    resetDu(): void;
    get duInput(): boolean | cdktf.IResolvable | undefined;
    private _keyboard?;
    get keyboard(): string;
    set keyboard(value: string);
    resetKeyboard(): void;
    get keyboardInput(): string | undefined;
    private _paste?;
    get paste(): string;
    set paste(value: string);
    resetPaste(): void;
    get pasteInput(): string | undefined;
    private _printing?;
    get printing(): string;
    set printing(value: string);
    resetPrinting(): void;
    get printingInput(): string | undefined;
    private _upload?;
    get upload(): string;
    set upload(value: string);
    resetUpload(): void;
    get uploadInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsBlockPage {
    /**
    * If true, context information will be passed as query parameters
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#include_context ZeroTrustGatewayPolicy#include_context}
    */
    readonly includeContext?: boolean | cdktf.IResolvable;
    /**
    * URI to which the user will be redirected
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#target_uri ZeroTrustGatewayPolicy#target_uri}
    */
    readonly targetUri: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsBlockPageToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsBlockPage | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsBlockPageToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsBlockPage | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsBlockPageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsBlockPage | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsBlockPage | cdktf.IResolvable | undefined);
    private _includeContext?;
    get includeContext(): boolean | cdktf.IResolvable;
    set includeContext(value: boolean | cdktf.IResolvable);
    resetIncludeContext(): void;
    get includeContextInput(): boolean | cdktf.IResolvable | undefined;
    private _targetUri?;
    get targetUri(): string;
    set targetUri(value: string);
    get targetUriInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsCheckSession {
    /**
    * Configure how fresh the session needs to be to be considered valid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#duration ZeroTrustGatewayPolicy#duration}
    */
    readonly duration?: string;
    /**
    * Set to true to enable session enforcement.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#enforce ZeroTrustGatewayPolicy#enforce}
    */
    readonly enforce?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsCheckSessionToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsCheckSession | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsCheckSessionToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsCheckSession | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsCheckSessionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsCheckSession | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsCheckSession | cdktf.IResolvable | undefined);
    private _duration?;
    get duration(): string;
    set duration(value: string);
    resetDuration(): void;
    get durationInput(): string | undefined;
    private _enforce?;
    get enforce(): boolean | cdktf.IResolvable;
    set enforce(value: boolean | cdktf.IResolvable);
    resetEnforce(): void;
    get enforceInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 {
    /**
    * IPv4 address of upstream resolver.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ip ZeroTrustGatewayPolicy#ip}
    */
    readonly ip: string;
    /**
    * A port number to use for upstream resolver. Defaults to 53 if unspecified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#port ZeroTrustGatewayPolicy#port}
    */
    readonly port?: number;
    /**
    * Whether to connect to this resolver over a private network. Must be set when vnet_id is set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#route_through_private_network ZeroTrustGatewayPolicy#route_through_private_network}
    */
    readonly routeThroughPrivateNetwork?: boolean | cdktf.IResolvable;
    /**
    * Optionally specify a virtual network for this resolver. Uses default virtual network id if omitted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#vnet_id ZeroTrustGatewayPolicy#vnet_id}
    */
    readonly vnetId?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4ToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4ToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable | undefined);
    private _ip?;
    get ip(): string;
    set ip(value: string);
    get ipInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _routeThroughPrivateNetwork?;
    get routeThroughPrivateNetwork(): boolean | cdktf.IResolvable;
    set routeThroughPrivateNetwork(value: boolean | cdktf.IResolvable);
    resetRouteThroughPrivateNetwork(): void;
    get routeThroughPrivateNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _vnetId?;
    get vnetId(): string;
    set vnetId(value: string);
    resetVnetId(): void;
    get vnetIdInput(): string | undefined;
}
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4List extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4OutputReference;
}
export interface ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 {
    /**
    * IPv6 address of upstream resolver.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ip ZeroTrustGatewayPolicy#ip}
    */
    readonly ip: string;
    /**
    * A port number to use for upstream resolver. Defaults to 53 if unspecified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#port ZeroTrustGatewayPolicy#port}
    */
    readonly port?: number;
    /**
    * Whether to connect to this resolver over a private network. Must be set when vnet_id is set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#route_through_private_network ZeroTrustGatewayPolicy#route_through_private_network}
    */
    readonly routeThroughPrivateNetwork?: boolean | cdktf.IResolvable;
    /**
    * Optionally specify a virtual network for this resolver. Uses default virtual network id if omitted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#vnet_id ZeroTrustGatewayPolicy#vnet_id}
    */
    readonly vnetId?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6ToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6ToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable | undefined);
    private _ip?;
    get ip(): string;
    set ip(value: string);
    get ipInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _routeThroughPrivateNetwork?;
    get routeThroughPrivateNetwork(): boolean | cdktf.IResolvable;
    set routeThroughPrivateNetwork(value: boolean | cdktf.IResolvable);
    resetRouteThroughPrivateNetwork(): void;
    get routeThroughPrivateNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _vnetId?;
    get vnetId(): string;
    set vnetId(value: string);
    resetVnetId(): void;
    get vnetIdInput(): string | undefined;
}
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6List extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6OutputReference;
}
export interface ZeroTrustGatewayPolicyRuleSettingsDnsResolvers {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ipv4 ZeroTrustGatewayPolicy#ipv4}
    */
    readonly ipv4?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ipv6 ZeroTrustGatewayPolicy#ipv6}
    */
    readonly ipv6?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | cdktf.IResolvable | undefined);
    private _ipv4;
    get ipv4(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4List;
    putIpv4(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | cdktf.IResolvable): void;
    resetIpv4(): void;
    get ipv4Input(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | undefined;
    private _ipv6;
    get ipv6(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6List;
    putIpv6(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | cdktf.IResolvable): void;
    resetIpv6(): void;
    get ipv6Input(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsEgress {
    /**
    * The IPv4 address to be used for egress.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ipv4 ZeroTrustGatewayPolicy#ipv4}
    */
    readonly ipv4?: string;
    /**
    * The fallback IPv4 address to be used for egress in the event of an error egressing with the primary IPv4. Can be '0.0.0.0' to indicate local egress via WARP IPs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ipv4_fallback ZeroTrustGatewayPolicy#ipv4_fallback}
    */
    readonly ipv4Fallback?: string;
    /**
    * The IPv6 range to be used for egress.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ipv6 ZeroTrustGatewayPolicy#ipv6}
    */
    readonly ipv6?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsEgressToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsEgress | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsEgressToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsEgress | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsEgressOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsEgress | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsEgress | cdktf.IResolvable | undefined);
    private _ipv4?;
    get ipv4(): string;
    set ipv4(value: string);
    resetIpv4(): void;
    get ipv4Input(): string | undefined;
    private _ipv4Fallback?;
    get ipv4Fallback(): string;
    set ipv4Fallback(value: string);
    resetIpv4Fallback(): void;
    get ipv4FallbackInput(): string | undefined;
    private _ipv6?;
    get ipv6(): string;
    set ipv6(value: string);
    resetIpv6(): void;
    get ipv6Input(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsL4Override {
    /**
    * IPv4 or IPv6 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ip ZeroTrustGatewayPolicy#ip}
    */
    readonly ip?: string;
    /**
    * A port number to use for TCP/UDP overrides.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#port ZeroTrustGatewayPolicy#port}
    */
    readonly port?: number;
}
export declare function zeroTrustGatewayPolicyRuleSettingsL4OverrideToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsL4Override | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsL4OverrideToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsL4Override | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsL4OverrideOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsL4Override | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsL4Override | cdktf.IResolvable | undefined);
    private _ip?;
    get ip(): string;
    set ip(value: string);
    resetIp(): void;
    get ipInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsNotificationSettings {
    /**
    * Set notification on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#enabled ZeroTrustGatewayPolicy#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * If true, context information will be passed as query parameters
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#include_context ZeroTrustGatewayPolicy#include_context}
    */
    readonly includeContext?: boolean | cdktf.IResolvable;
    /**
    * Customize the message shown in the notification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#msg ZeroTrustGatewayPolicy#msg}
    */
    readonly msg?: string;
    /**
    * Optional URL to direct users to additional information. If not set, the notification will open a block page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#support_url ZeroTrustGatewayPolicy#support_url}
    */
    readonly supportUrl?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsNotificationSettingsToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsNotificationSettingsToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsNotificationSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _includeContext?;
    get includeContext(): boolean | cdktf.IResolvable;
    set includeContext(value: boolean | cdktf.IResolvable);
    resetIncludeContext(): void;
    get includeContextInput(): boolean | cdktf.IResolvable | undefined;
    private _msg?;
    get msg(): string;
    set msg(value: string);
    resetMsg(): void;
    get msgInput(): string | undefined;
    private _supportUrl?;
    get supportUrl(): string;
    set supportUrl(value: string);
    resetSupportUrl(): void;
    get supportUrlInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsPayloadLog {
    /**
    * Set to true to enable DLP payload logging for this rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#enabled ZeroTrustGatewayPolicy#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsPayloadLogToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsPayloadLog | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsPayloadLogToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsPayloadLog | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsPayloadLogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsPayloadLog | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsPayloadLog | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsQuarantine {
    /**
    * Types of files to sandbox.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#file_types ZeroTrustGatewayPolicy#file_types}
    */
    readonly fileTypes?: string[];
}
export declare function zeroTrustGatewayPolicyRuleSettingsQuarantineToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsQuarantine | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsQuarantineToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsQuarantine | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsQuarantineOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsQuarantine | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsQuarantine | cdktf.IResolvable | undefined);
    private _fileTypes?;
    get fileTypes(): string[];
    set fileTypes(value: string[]);
    resetFileTypes(): void;
    get fileTypesInput(): string[] | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsRedirect {
    /**
    * If true, context information will be passed as query parameters
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#include_context ZeroTrustGatewayPolicy#include_context}
    */
    readonly includeContext?: boolean | cdktf.IResolvable;
    /**
    * If true, the path and query parameters from the original request will be appended to target_uri
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#preserve_path_and_query ZeroTrustGatewayPolicy#preserve_path_and_query}
    */
    readonly preservePathAndQuery?: boolean | cdktf.IResolvable;
    /**
    * URI to which the user will be redirected
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#target_uri ZeroTrustGatewayPolicy#target_uri}
    */
    readonly targetUri: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsRedirectToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsRedirect | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsRedirectToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsRedirect | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsRedirectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsRedirect | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsRedirect | cdktf.IResolvable | undefined);
    private _includeContext?;
    get includeContext(): boolean | cdktf.IResolvable;
    set includeContext(value: boolean | cdktf.IResolvable);
    resetIncludeContext(): void;
    get includeContextInput(): boolean | cdktf.IResolvable | undefined;
    private _preservePathAndQuery?;
    get preservePathAndQuery(): boolean | cdktf.IResolvable;
    set preservePathAndQuery(value: boolean | cdktf.IResolvable);
    resetPreservePathAndQuery(): void;
    get preservePathAndQueryInput(): boolean | cdktf.IResolvable | undefined;
    private _targetUri?;
    get targetUri(): string;
    set targetUri(value: string);
    get targetUriInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally {
    /**
    * The fallback behavior to apply when the internal DNS response code is different from 'NOERROR' or when the response data only contains CNAME records for 'A' or 'AAAA' queries.
    * Available values: "none", "public_dns".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#fallback ZeroTrustGatewayPolicy#fallback}
    */
    readonly fallback?: string;
    /**
    * The internal DNS view identifier that's passed to the internal DNS service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#view_id ZeroTrustGatewayPolicy#view_id}
    */
    readonly viewId?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsResolveDnsInternallyToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsResolveDnsInternallyToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternallyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally | cdktf.IResolvable | undefined);
    private _fallback?;
    get fallback(): string;
    set fallback(value: string);
    resetFallback(): void;
    get fallbackInput(): string | undefined;
    private _viewId?;
    get viewId(): string;
    set viewId(value: string);
    resetViewId(): void;
    get viewIdInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsUntrustedCert {
    /**
    * The action performed when an untrusted certificate is seen. The default action is an error with HTTP code 526.
    * Available values: "pass_through", "block", "error".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#action ZeroTrustGatewayPolicy#action}
    */
    readonly action?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsUntrustedCertToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsUntrustedCertToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsUntrustedCertOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | cdktf.IResolvable | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettings {
    /**
    * Add custom headers to allowed requests, in the form of key-value pairs. Keys are header names, pointing to an array with its header value(s).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#add_headers ZeroTrustGatewayPolicy#add_headers}
    */
    readonly addHeaders?: {
        [key: string]: string;
    };
    /**
    * Set by parent MSP accounts to enable their children to bypass this rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#allow_child_bypass ZeroTrustGatewayPolicy#allow_child_bypass}
    */
    readonly allowChildBypass?: boolean | cdktf.IResolvable;
    /**
    * Settings for the Audit SSH action.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#audit_ssh ZeroTrustGatewayPolicy#audit_ssh}
    */
    readonly auditSsh?: ZeroTrustGatewayPolicyRuleSettingsAuditSsh;
    /**
    * Configure how browser isolation behaves.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#biso_admin_controls ZeroTrustGatewayPolicy#biso_admin_controls}
    */
    readonly bisoAdminControls?: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls;
    /**
    * Custom block page settings. If missing/null, blocking will use the the account settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#block_page ZeroTrustGatewayPolicy#block_page}
    */
    readonly blockPage?: ZeroTrustGatewayPolicyRuleSettingsBlockPage;
    /**
    * Enable the custom block page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#block_page_enabled ZeroTrustGatewayPolicy#block_page_enabled}
    */
    readonly blockPageEnabled?: boolean | cdktf.IResolvable;
    /**
    * The text describing why this block occurred, displayed on the custom block page (if enabled).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#block_reason ZeroTrustGatewayPolicy#block_reason}
    */
    readonly blockReason?: string;
    /**
    * Set by children MSP accounts to bypass their parent's rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#bypass_parent_rule ZeroTrustGatewayPolicy#bypass_parent_rule}
    */
    readonly bypassParentRule?: boolean | cdktf.IResolvable;
    /**
    * Configure how session check behaves.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#check_session ZeroTrustGatewayPolicy#check_session}
    */
    readonly checkSession?: ZeroTrustGatewayPolicyRuleSettingsCheckSession;
    /**
    * Add your own custom resolvers to route queries that match the resolver policy. Cannot be used when 'resolve_dns_through_cloudflare' or 'resolve_dns_internally' are set. DNS queries will route to the address closest to their origin. Only valid when a rule's action is set to 'resolve'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#dns_resolvers ZeroTrustGatewayPolicy#dns_resolvers}
    */
    readonly dnsResolvers?: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers;
    /**
    * Configure how Gateway Proxy traffic egresses. You can enable this setting for rules with Egress actions and filters, or omit it to indicate local egress via WARP IPs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#egress ZeroTrustGatewayPolicy#egress}
    */
    readonly egress?: ZeroTrustGatewayPolicyRuleSettingsEgress;
    /**
    * Set to true, to ignore the category matches at CNAME domains in a response. If unchecked, the categories in this rule will be checked against all the CNAME domain categories in a response.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ignore_cname_category_matches ZeroTrustGatewayPolicy#ignore_cname_category_matches}
    */
    readonly ignoreCnameCategoryMatches?: boolean | cdktf.IResolvable;
    /**
    * INSECURE - disable DNSSEC validation (for Allow actions).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#insecure_disable_dnssec_validation ZeroTrustGatewayPolicy#insecure_disable_dnssec_validation}
    */
    readonly insecureDisableDnssecValidation?: boolean | cdktf.IResolvable;
    /**
    * Set to true to enable IPs in DNS resolver category blocks. By default categories only block based on domain names.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ip_categories ZeroTrustGatewayPolicy#ip_categories}
    */
    readonly ipCategories?: boolean | cdktf.IResolvable;
    /**
    * Set to true to include IPs in DNS resolver indicator feed blocks. By default indicator feeds only block based on domain names.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#ip_indicator_feeds ZeroTrustGatewayPolicy#ip_indicator_feeds}
    */
    readonly ipIndicatorFeeds?: boolean | cdktf.IResolvable;
    /**
    * Send matching traffic to the supplied destination IP address and port.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#l4override ZeroTrustGatewayPolicy#l4override}
    */
    readonly l4Override?: ZeroTrustGatewayPolicyRuleSettingsL4Override;
    /**
    * Configure a notification to display on the user's device when this rule is matched.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#notification_settings ZeroTrustGatewayPolicy#notification_settings}
    */
    readonly notificationSettings?: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings;
    /**
    * Override matching DNS queries with a hostname.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#override_host ZeroTrustGatewayPolicy#override_host}
    */
    readonly overrideHost?: string;
    /**
    * Override matching DNS queries with an IP or set of IPs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#override_ips ZeroTrustGatewayPolicy#override_ips}
    */
    readonly overrideIps?: string[];
    /**
    * Configure DLP payload logging.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#payload_log ZeroTrustGatewayPolicy#payload_log}
    */
    readonly payloadLog?: ZeroTrustGatewayPolicyRuleSettingsPayloadLog;
    /**
    * Settings that apply to quarantine rules
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#quarantine ZeroTrustGatewayPolicy#quarantine}
    */
    readonly quarantine?: ZeroTrustGatewayPolicyRuleSettingsQuarantine;
    /**
    * Settings that apply to redirect rules
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#redirect ZeroTrustGatewayPolicy#redirect}
    */
    readonly redirect?: ZeroTrustGatewayPolicyRuleSettingsRedirect;
    /**
    * Configure to forward the query to the internal DNS service, passing the specified 'view_id' as input. Cannot be set when 'dns_resolvers' are specified or 'resolve_dns_through_cloudflare' is set. Only valid when a rule's action is set to 'resolve'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#resolve_dns_internally ZeroTrustGatewayPolicy#resolve_dns_internally}
    */
    readonly resolveDnsInternally?: ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally;
    /**
    * Enable to send queries that match the policy to Cloudflare's default 1.1.1.1 DNS resolver. Cannot be set when 'dns_resolvers' are specified or 'resolve_dns_internally' is set. Only valid when a rule's action is set to 'resolve'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#resolve_dns_through_cloudflare ZeroTrustGatewayPolicy#resolve_dns_through_cloudflare}
    */
    readonly resolveDnsThroughCloudflare?: boolean | cdktf.IResolvable;
    /**
    * Configure behavior when an upstream cert is invalid or an SSL error occurs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#untrusted_cert ZeroTrustGatewayPolicy#untrusted_cert}
    */
    readonly untrustedCert?: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert;
}
export declare function zeroTrustGatewayPolicyRuleSettingsToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettings | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettings | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettings | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettings | cdktf.IResolvable | undefined);
    private _addHeaders?;
    get addHeaders(): {
        [key: string]: string;
    };
    set addHeaders(value: {
        [key: string]: string;
    });
    resetAddHeaders(): void;
    get addHeadersInput(): {
        [key: string]: string;
    } | undefined;
    private _allowChildBypass?;
    get allowChildBypass(): boolean | cdktf.IResolvable;
    set allowChildBypass(value: boolean | cdktf.IResolvable);
    resetAllowChildBypass(): void;
    get allowChildBypassInput(): boolean | cdktf.IResolvable | undefined;
    private _auditSsh;
    get auditSsh(): ZeroTrustGatewayPolicyRuleSettingsAuditSshOutputReference;
    putAuditSsh(value: ZeroTrustGatewayPolicyRuleSettingsAuditSsh): void;
    resetAuditSsh(): void;
    get auditSshInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsAuditSsh | undefined;
    private _bisoAdminControls;
    get bisoAdminControls(): ZeroTrustGatewayPolicyRuleSettingsBisoAdminControlsOutputReference;
    putBisoAdminControls(value: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls): void;
    resetBisoAdminControls(): void;
    get bisoAdminControlsInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | undefined;
    private _blockPage;
    get blockPage(): ZeroTrustGatewayPolicyRuleSettingsBlockPageOutputReference;
    putBlockPage(value: ZeroTrustGatewayPolicyRuleSettingsBlockPage): void;
    resetBlockPage(): void;
    get blockPageInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsBlockPage | undefined;
    private _blockPageEnabled?;
    get blockPageEnabled(): boolean | cdktf.IResolvable;
    set blockPageEnabled(value: boolean | cdktf.IResolvable);
    resetBlockPageEnabled(): void;
    get blockPageEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _blockReason?;
    get blockReason(): string;
    set blockReason(value: string);
    resetBlockReason(): void;
    get blockReasonInput(): string | undefined;
    private _bypassParentRule?;
    get bypassParentRule(): boolean | cdktf.IResolvable;
    set bypassParentRule(value: boolean | cdktf.IResolvable);
    resetBypassParentRule(): void;
    get bypassParentRuleInput(): boolean | cdktf.IResolvable | undefined;
    private _checkSession;
    get checkSession(): ZeroTrustGatewayPolicyRuleSettingsCheckSessionOutputReference;
    putCheckSession(value: ZeroTrustGatewayPolicyRuleSettingsCheckSession): void;
    resetCheckSession(): void;
    get checkSessionInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsCheckSession | undefined;
    private _dnsResolvers;
    get dnsResolvers(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversOutputReference;
    putDnsResolvers(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers): void;
    resetDnsResolvers(): void;
    get dnsResolversInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | undefined;
    private _egress;
    get egress(): ZeroTrustGatewayPolicyRuleSettingsEgressOutputReference;
    putEgress(value: ZeroTrustGatewayPolicyRuleSettingsEgress): void;
    resetEgress(): void;
    get egressInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsEgress | undefined;
    private _ignoreCnameCategoryMatches?;
    get ignoreCnameCategoryMatches(): boolean | cdktf.IResolvable;
    set ignoreCnameCategoryMatches(value: boolean | cdktf.IResolvable);
    resetIgnoreCnameCategoryMatches(): void;
    get ignoreCnameCategoryMatchesInput(): boolean | cdktf.IResolvable | undefined;
    private _insecureDisableDnssecValidation?;
    get insecureDisableDnssecValidation(): boolean | cdktf.IResolvable;
    set insecureDisableDnssecValidation(value: boolean | cdktf.IResolvable);
    resetInsecureDisableDnssecValidation(): void;
    get insecureDisableDnssecValidationInput(): boolean | cdktf.IResolvable | undefined;
    private _ipCategories?;
    get ipCategories(): boolean | cdktf.IResolvable;
    set ipCategories(value: boolean | cdktf.IResolvable);
    resetIpCategories(): void;
    get ipCategoriesInput(): boolean | cdktf.IResolvable | undefined;
    private _ipIndicatorFeeds?;
    get ipIndicatorFeeds(): boolean | cdktf.IResolvable;
    set ipIndicatorFeeds(value: boolean | cdktf.IResolvable);
    resetIpIndicatorFeeds(): void;
    get ipIndicatorFeedsInput(): boolean | cdktf.IResolvable | undefined;
    private _l4Override;
    get l4Override(): ZeroTrustGatewayPolicyRuleSettingsL4OverrideOutputReference;
    putL4Override(value: ZeroTrustGatewayPolicyRuleSettingsL4Override): void;
    resetL4Override(): void;
    get l4OverrideInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsL4Override | undefined;
    private _notificationSettings;
    get notificationSettings(): ZeroTrustGatewayPolicyRuleSettingsNotificationSettingsOutputReference;
    putNotificationSettings(value: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings): void;
    resetNotificationSettings(): void;
    get notificationSettingsInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | undefined;
    private _overrideHost?;
    get overrideHost(): string;
    set overrideHost(value: string);
    resetOverrideHost(): void;
    get overrideHostInput(): string | undefined;
    private _overrideIps?;
    get overrideIps(): string[];
    set overrideIps(value: string[]);
    resetOverrideIps(): void;
    get overrideIpsInput(): string[] | undefined;
    private _payloadLog;
    get payloadLog(): ZeroTrustGatewayPolicyRuleSettingsPayloadLogOutputReference;
    putPayloadLog(value: ZeroTrustGatewayPolicyRuleSettingsPayloadLog): void;
    resetPayloadLog(): void;
    get payloadLogInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsPayloadLog | undefined;
    private _quarantine;
    get quarantine(): ZeroTrustGatewayPolicyRuleSettingsQuarantineOutputReference;
    putQuarantine(value: ZeroTrustGatewayPolicyRuleSettingsQuarantine): void;
    resetQuarantine(): void;
    get quarantineInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsQuarantine | undefined;
    private _redirect;
    get redirect(): ZeroTrustGatewayPolicyRuleSettingsRedirectOutputReference;
    putRedirect(value: ZeroTrustGatewayPolicyRuleSettingsRedirect): void;
    resetRedirect(): void;
    get redirectInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsRedirect | undefined;
    private _resolveDnsInternally;
    get resolveDnsInternally(): ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternallyOutputReference;
    putResolveDnsInternally(value: ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally): void;
    resetResolveDnsInternally(): void;
    get resolveDnsInternallyInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsResolveDnsInternally | undefined;
    private _resolveDnsThroughCloudflare?;
    get resolveDnsThroughCloudflare(): boolean | cdktf.IResolvable;
    set resolveDnsThroughCloudflare(value: boolean | cdktf.IResolvable);
    resetResolveDnsThroughCloudflare(): void;
    get resolveDnsThroughCloudflareInput(): boolean | cdktf.IResolvable | undefined;
    private _untrustedCert;
    get untrustedCert(): ZeroTrustGatewayPolicyRuleSettingsUntrustedCertOutputReference;
    putUntrustedCert(value: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert): void;
    resetUntrustedCert(): void;
    get untrustedCertInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | undefined;
}
export interface ZeroTrustGatewayPolicySchedule {
    /**
    * The time intervals when the rule will be active on Fridays, in increasing order from 00:00-24:00.  If this parameter is omitted, the rule will be deactivated on Fridays.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#fri ZeroTrustGatewayPolicy#fri}
    */
    readonly fri?: string;
    /**
    * The time intervals when the rule will be active on Mondays, in increasing order from 00:00-24:00. If this parameter is omitted, the rule will be deactivated on Mondays.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#mon ZeroTrustGatewayPolicy#mon}
    */
    readonly mon?: string;
    /**
    * The time intervals when the rule will be active on Saturdays, in increasing order from 00:00-24:00.  If this parameter is omitted, the rule will be deactivated on Saturdays.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#sat ZeroTrustGatewayPolicy#sat}
    */
    readonly sat?: string;
    /**
    * The time intervals when the rule will be active on Sundays, in increasing order from 00:00-24:00. If this parameter is omitted, the rule will be deactivated on Sundays.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#sun ZeroTrustGatewayPolicy#sun}
    */
    readonly sun?: string;
    /**
    * The time intervals when the rule will be active on Thursdays, in increasing order from 00:00-24:00. If this parameter is omitted, the rule will be deactivated on Thursdays.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#thu ZeroTrustGatewayPolicy#thu}
    */
    readonly thu?: string;
    /**
    * The time zone the rule will be evaluated against. If a [valid time zone city name](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List) is provided, Gateway will always use the current time at that time zone. If this parameter is omitted, then Gateway will use the time zone inferred from the user's source IP to evaluate the rule. If Gateway cannot determine the time zone from the IP, we will fall back to the time zone of the user's connected data center.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#time_zone ZeroTrustGatewayPolicy#time_zone}
    */
    readonly timeZone?: string;
    /**
    * The time intervals when the rule will be active on Tuesdays, in increasing order from 00:00-24:00. If this parameter is omitted, the rule will be deactivated on Tuesdays.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#tue ZeroTrustGatewayPolicy#tue}
    */
    readonly tue?: string;
    /**
    * The time intervals when the rule will be active on Wednesdays, in increasing order from 00:00-24:00. If this parameter is omitted, the rule will be deactivated on Wednesdays.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#wed ZeroTrustGatewayPolicy#wed}
    */
    readonly wed?: string;
}
export declare function zeroTrustGatewayPolicyScheduleToTerraform(struct?: ZeroTrustGatewayPolicySchedule | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyScheduleToHclTerraform(struct?: ZeroTrustGatewayPolicySchedule | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicySchedule | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicySchedule | cdktf.IResolvable | undefined);
    private _fri?;
    get fri(): string;
    set fri(value: string);
    resetFri(): void;
    get friInput(): string | undefined;
    private _mon?;
    get mon(): string;
    set mon(value: string);
    resetMon(): void;
    get monInput(): string | undefined;
    private _sat?;
    get sat(): string;
    set sat(value: string);
    resetSat(): void;
    get satInput(): string | undefined;
    private _sun?;
    get sun(): string;
    set sun(value: string);
    resetSun(): void;
    get sunInput(): string | undefined;
    private _thu?;
    get thu(): string;
    set thu(value: string);
    resetThu(): void;
    get thuInput(): string | undefined;
    private _timeZone?;
    get timeZone(): string;
    set timeZone(value: string);
    resetTimeZone(): void;
    get timeZoneInput(): string | undefined;
    private _tue?;
    get tue(): string;
    set tue(value: string);
    resetTue(): void;
    get tueInput(): string | undefined;
    private _wed?;
    get wed(): string;
    set wed(value: string);
    resetWed(): void;
    get wedInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy cloudflare_zero_trust_gateway_policy}
*/
export declare class ZeroTrustGatewayPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_gateway_policy";
    /**
    * Generates CDKTF code for importing a ZeroTrustGatewayPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustGatewayPolicy to import
    * @param importFromId The id of the existing ZeroTrustGatewayPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustGatewayPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_policy cloudflare_zero_trust_gateway_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustGatewayPolicyConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustGatewayPolicyConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    get createdAt(): string;
    get deletedAt(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _devicePosture?;
    get devicePosture(): string;
    set devicePosture(value: string);
    resetDevicePosture(): void;
    get devicePostureInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _expiration;
    get expiration(): ZeroTrustGatewayPolicyExpirationOutputReference;
    putExpiration(value: ZeroTrustGatewayPolicyExpiration): void;
    resetExpiration(): void;
    get expirationInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyExpiration | undefined;
    private _filters?;
    get filters(): string[];
    set filters(value: string[]);
    resetFilters(): void;
    get filtersInput(): string[] | undefined;
    get id(): string;
    private _identity?;
    get identity(): string;
    set identity(value: string);
    resetIdentity(): void;
    get identityInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _precedence?;
    get precedence(): number;
    set precedence(value: number);
    resetPrecedence(): void;
    get precedenceInput(): number | undefined;
    private _ruleSettings;
    get ruleSettings(): ZeroTrustGatewayPolicyRuleSettingsOutputReference;
    putRuleSettings(value: ZeroTrustGatewayPolicyRuleSettings): void;
    resetRuleSettings(): void;
    get ruleSettingsInput(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettings | undefined;
    private _schedule;
    get schedule(): ZeroTrustGatewayPolicyScheduleOutputReference;
    putSchedule(value: ZeroTrustGatewayPolicySchedule): void;
    resetSchedule(): void;
    get scheduleInput(): cdktf.IResolvable | ZeroTrustGatewayPolicySchedule | undefined;
    private _traffic?;
    get traffic(): string;
    set traffic(value: string);
    resetTraffic(): void;
    get trafficInput(): string | undefined;
    get updatedAt(): string;
    get version(): number;
    get warningStatus(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
