/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustGatewaySettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#account_id ZeroTrustGatewaySettings#account_id}
    */
    readonly accountId: string;
    /**
    * Account settings
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#settings ZeroTrustGatewaySettings#settings}
    */
    readonly settings?: ZeroTrustGatewaySettingsSettings;
}
export interface ZeroTrustGatewaySettingsSettingsActivityLog {
    /**
    * Enable activity logging.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsActivityLogToTerraform(struct?: ZeroTrustGatewaySettingsSettingsActivityLog | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsActivityLogToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsActivityLog | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsActivityLogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsActivityLog | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsActivityLog | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings {
    /**
    * Set notification on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * If true, context information will be passed as query parameters
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#include_context ZeroTrustGatewaySettings#include_context}
    */
    readonly includeContext?: boolean | cdktf.IResolvable;
    /**
    * Customize the message shown in the notification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#msg ZeroTrustGatewaySettings#msg}
    */
    readonly msg?: string;
    /**
    * Optional URL to direct users to additional information. If not set, the notification will open a block page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#support_url ZeroTrustGatewaySettings#support_url}
    */
    readonly supportUrl?: string;
}
export declare function zeroTrustGatewaySettingsSettingsAntivirusNotificationSettingsToTerraform(struct?: ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsAntivirusNotificationSettingsToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _includeContext?;
    get includeContext(): boolean | cdktf.IResolvable;
    set includeContext(value: boolean | cdktf.IResolvable);
    resetIncludeContext(): void;
    get includeContextInput(): boolean | cdktf.IResolvable | undefined;
    private _msg?;
    get msg(): string;
    set msg(value: string);
    resetMsg(): void;
    get msgInput(): string | undefined;
    private _supportUrl?;
    get supportUrl(): string;
    set supportUrl(value: string);
    resetSupportUrl(): void;
    get supportUrlInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsAntivirus {
    /**
    * Enable anti-virus scanning on downloads.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled_download_phase ZeroTrustGatewaySettings#enabled_download_phase}
    */
    readonly enabledDownloadPhase?: boolean | cdktf.IResolvable;
    /**
    * Enable anti-virus scanning on uploads.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled_upload_phase ZeroTrustGatewaySettings#enabled_upload_phase}
    */
    readonly enabledUploadPhase?: boolean | cdktf.IResolvable;
    /**
    * Block requests for files that cannot be scanned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#fail_closed ZeroTrustGatewaySettings#fail_closed}
    */
    readonly failClosed?: boolean | cdktf.IResolvable;
    /**
    * Configure a message to display on the user's device when an antivirus search is performed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#notification_settings ZeroTrustGatewaySettings#notification_settings}
    */
    readonly notificationSettings?: ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings;
}
export declare function zeroTrustGatewaySettingsSettingsAntivirusToTerraform(struct?: ZeroTrustGatewaySettingsSettingsAntivirus | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsAntivirusToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsAntivirus | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsAntivirusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsAntivirus | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsAntivirus | cdktf.IResolvable | undefined);
    private _enabledDownloadPhase?;
    get enabledDownloadPhase(): boolean | cdktf.IResolvable;
    set enabledDownloadPhase(value: boolean | cdktf.IResolvable);
    resetEnabledDownloadPhase(): void;
    get enabledDownloadPhaseInput(): boolean | cdktf.IResolvable | undefined;
    private _enabledUploadPhase?;
    get enabledUploadPhase(): boolean | cdktf.IResolvable;
    set enabledUploadPhase(value: boolean | cdktf.IResolvable);
    resetEnabledUploadPhase(): void;
    get enabledUploadPhaseInput(): boolean | cdktf.IResolvable | undefined;
    private _failClosed?;
    get failClosed(): boolean | cdktf.IResolvable;
    set failClosed(value: boolean | cdktf.IResolvable);
    resetFailClosed(): void;
    get failClosedInput(): boolean | cdktf.IResolvable | undefined;
    private _notificationSettings;
    get notificationSettings(): ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettingsOutputReference;
    putNotificationSettings(value: ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings): void;
    resetNotificationSettings(): void;
    get notificationSettingsInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsAntivirusNotificationSettings | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsAppControlSettings {
    /**
    * Enable App Control
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsAppControlSettingsToTerraform(struct?: ZeroTrustGatewaySettingsSettingsAppControlSettings | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsAppControlSettingsToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsAppControlSettings | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsAppControlSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsAppControlSettings | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsAppControlSettings | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsBlockPage {
    /**
    * If mode is customized_block_page: block page background color in #rrggbb format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#background_color ZeroTrustGatewaySettings#background_color}
    */
    readonly backgroundColor?: string;
    /**
    * Enable only cipher suites and TLS versions compliant with FIPS 140-2.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * If mode is customized_block_page: block page footer text.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#footer_text ZeroTrustGatewaySettings#footer_text}
    */
    readonly footerText?: string;
    /**
    * If mode is customized_block_page: block page header text.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#header_text ZeroTrustGatewaySettings#header_text}
    */
    readonly headerText?: string;
    /**
    * If mode is redirect_uri: when enabled, context will be appended to target_uri as query parameters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#include_context ZeroTrustGatewaySettings#include_context}
    */
    readonly includeContext?: boolean | cdktf.IResolvable;
    /**
    * If mode is customized_block_page: full URL to the logo file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#logo_path ZeroTrustGatewaySettings#logo_path}
    */
    readonly logoPath?: string;
    /**
    * If mode is customized_block_page: admin email for users to contact.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#mailto_address ZeroTrustGatewaySettings#mailto_address}
    */
    readonly mailtoAddress?: string;
    /**
    * If mode is customized_block_page: subject line for emails created from block page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#mailto_subject ZeroTrustGatewaySettings#mailto_subject}
    */
    readonly mailtoSubject?: string;
    /**
    * Controls whether the user is redirected to a Cloudflare-hosted block page or to a customer-provided URI.
    * Available values: "customized_block_page", "redirect_uri".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#mode ZeroTrustGatewaySettings#mode}
    */
    readonly mode?: string;
    /**
    * If mode is customized_block_page: block page title.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#name ZeroTrustGatewaySettings#name}
    */
    readonly name?: string;
    /**
    * If mode is customized_block_page: suppress detailed info at the bottom of the block page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#suppress_footer ZeroTrustGatewaySettings#suppress_footer}
    */
    readonly suppressFooter?: boolean | cdktf.IResolvable;
    /**
    * If mode is redirect_uri: URI to which the user should be redirected.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#target_uri ZeroTrustGatewaySettings#target_uri}
    */
    readonly targetUri?: string;
}
export declare function zeroTrustGatewaySettingsSettingsBlockPageToTerraform(struct?: ZeroTrustGatewaySettingsSettingsBlockPage | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsBlockPageToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsBlockPage | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsBlockPageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsBlockPage | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsBlockPage | cdktf.IResolvable | undefined);
    private _backgroundColor?;
    get backgroundColor(): string;
    set backgroundColor(value: string);
    resetBackgroundColor(): void;
    get backgroundColorInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _footerText?;
    get footerText(): string;
    set footerText(value: string);
    resetFooterText(): void;
    get footerTextInput(): string | undefined;
    private _headerText?;
    get headerText(): string;
    set headerText(value: string);
    resetHeaderText(): void;
    get headerTextInput(): string | undefined;
    private _includeContext?;
    get includeContext(): boolean | cdktf.IResolvable;
    set includeContext(value: boolean | cdktf.IResolvable);
    resetIncludeContext(): void;
    get includeContextInput(): boolean | cdktf.IResolvable | undefined;
    private _logoPath?;
    get logoPath(): string;
    set logoPath(value: string);
    resetLogoPath(): void;
    get logoPathInput(): string | undefined;
    private _mailtoAddress?;
    get mailtoAddress(): string;
    set mailtoAddress(value: string);
    resetMailtoAddress(): void;
    get mailtoAddressInput(): string | undefined;
    private _mailtoSubject?;
    get mailtoSubject(): string;
    set mailtoSubject(value: string);
    resetMailtoSubject(): void;
    get mailtoSubjectInput(): string | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _suppressFooter?;
    get suppressFooter(): boolean | cdktf.IResolvable;
    set suppressFooter(value: boolean | cdktf.IResolvable);
    resetSuppressFooter(): void;
    get suppressFooterInput(): boolean | cdktf.IResolvable | undefined;
    private _targetUri?;
    get targetUri(): string;
    set targetUri(value: string);
    resetTargetUri(): void;
    get targetUriInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsBodyScanning {
    /**
    * Set the inspection mode to either `deep` or `shallow`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#inspection_mode ZeroTrustGatewaySettings#inspection_mode}
    */
    readonly inspectionMode?: string;
}
export declare function zeroTrustGatewaySettingsSettingsBodyScanningToTerraform(struct?: ZeroTrustGatewaySettingsSettingsBodyScanning | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsBodyScanningToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsBodyScanning | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsBodyScanningOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsBodyScanning | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsBodyScanning | cdktf.IResolvable | undefined);
    private _inspectionMode?;
    get inspectionMode(): string;
    set inspectionMode(value: string);
    resetInspectionMode(): void;
    get inspectionModeInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsBrowserIsolation {
    /**
    * Enable non-identity onramp support for Browser Isolation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#non_identity_enabled ZeroTrustGatewaySettings#non_identity_enabled}
    */
    readonly nonIdentityEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable Clientless Browser Isolation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#url_browser_isolation_enabled ZeroTrustGatewaySettings#url_browser_isolation_enabled}
    */
    readonly urlBrowserIsolationEnabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsBrowserIsolationToTerraform(struct?: ZeroTrustGatewaySettingsSettingsBrowserIsolation | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsBrowserIsolationToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsBrowserIsolation | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsBrowserIsolationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsBrowserIsolation | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsBrowserIsolation | cdktf.IResolvable | undefined);
    private _nonIdentityEnabled?;
    get nonIdentityEnabled(): boolean | cdktf.IResolvable;
    set nonIdentityEnabled(value: boolean | cdktf.IResolvable);
    resetNonIdentityEnabled(): void;
    get nonIdentityEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _urlBrowserIsolationEnabled?;
    get urlBrowserIsolationEnabled(): boolean | cdktf.IResolvable;
    set urlBrowserIsolationEnabled(value: boolean | cdktf.IResolvable);
    resetUrlBrowserIsolationEnabled(): void;
    get urlBrowserIsolationEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsCertificate {
    /**
    * UUID of certificate to be used for interception. Certificate must be available (previously called 'active') on the edge. A nil UUID will indicate the Cloudflare Root CA should be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#id ZeroTrustGatewaySettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function zeroTrustGatewaySettingsSettingsCertificateToTerraform(struct?: ZeroTrustGatewaySettingsSettingsCertificate | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsCertificateToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsCertificate | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsCertificate | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsCertificate | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsCustomCertificate {
    /**
    * Enable use of custom certificate authority for signing Gateway traffic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * UUID of certificate (ID from MTLS certificate store).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#id ZeroTrustGatewaySettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export declare function zeroTrustGatewaySettingsSettingsCustomCertificateToTerraform(struct?: ZeroTrustGatewaySettingsSettingsCustomCertificate | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsCustomCertificateToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsCustomCertificate | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsCustomCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsCustomCertificate | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsCustomCertificate | cdktf.IResolvable | undefined);
    get bindingStatus(): string;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get updatedAt(): string;
}
export interface ZeroTrustGatewaySettingsSettingsExtendedEmailMatching {
    /**
    * Enable matching all variants of user emails (with + or . modifiers) used as criteria in Firewall policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsExtendedEmailMatchingToTerraform(struct?: ZeroTrustGatewaySettingsSettingsExtendedEmailMatching | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsExtendedEmailMatchingToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsExtendedEmailMatching | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsExtendedEmailMatchingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsExtendedEmailMatching | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsExtendedEmailMatching | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsFips {
    /**
    * Enable only cipher suites and TLS versions compliant with FIPS 140-2.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#tls ZeroTrustGatewaySettings#tls}
    */
    readonly tls?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsFipsToTerraform(struct?: ZeroTrustGatewaySettingsSettingsFips | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsFipsToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsFips | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsFipsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsFips | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsFips | cdktf.IResolvable | undefined);
    private _tls?;
    get tls(): boolean | cdktf.IResolvable;
    set tls(value: boolean | cdktf.IResolvable);
    resetTls(): void;
    get tlsInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsHostSelector {
    /**
    * Enable filtering via hosts for egress policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsHostSelectorToTerraform(struct?: ZeroTrustGatewaySettingsSettingsHostSelector | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsHostSelectorToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsHostSelector | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsHostSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsHostSelector | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsHostSelector | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsProtocolDetection {
    /**
    * Enable detecting protocol on initial bytes of client traffic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsProtocolDetectionToTerraform(struct?: ZeroTrustGatewaySettingsSettingsProtocolDetection | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsProtocolDetectionToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsProtocolDetection | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsProtocolDetectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsProtocolDetection | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsProtocolDetection | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsSandbox {
    /**
    * Enable sandbox.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Action to take when the file cannot be scanned.
    * Available values: "allow", "block".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#fallback_action ZeroTrustGatewaySettings#fallback_action}
    */
    readonly fallbackAction?: string;
}
export declare function zeroTrustGatewaySettingsSettingsSandboxToTerraform(struct?: ZeroTrustGatewaySettingsSettingsSandbox | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsSandboxToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsSandbox | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsSandboxOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsSandbox | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsSandbox | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _fallbackAction?;
    get fallbackAction(): string;
    set fallbackAction(value: string);
    resetFallbackAction(): void;
    get fallbackActionInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsSettingsTlsDecrypt {
    /**
    * Enable inspecting encrypted HTTP traffic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsSettingsTlsDecryptToTerraform(struct?: ZeroTrustGatewaySettingsSettingsTlsDecrypt | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsTlsDecryptToHclTerraform(struct?: ZeroTrustGatewaySettingsSettingsTlsDecrypt | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsTlsDecryptOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettingsTlsDecrypt | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettingsTlsDecrypt | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSettings {
    /**
    * Activity log settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#activity_log ZeroTrustGatewaySettings#activity_log}
    */
    readonly activityLog?: ZeroTrustGatewaySettingsSettingsActivityLog;
    /**
    * Anti-virus settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#antivirus ZeroTrustGatewaySettings#antivirus}
    */
    readonly antivirus?: ZeroTrustGatewaySettingsSettingsAntivirus;
    /**
    * Setting to enable App Control
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#app_control_settings ZeroTrustGatewaySettings#app_control_settings}
    */
    readonly appControlSettings?: ZeroTrustGatewaySettingsSettingsAppControlSettings;
    /**
    * Block page layout settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#block_page ZeroTrustGatewaySettings#block_page}
    */
    readonly blockPage?: ZeroTrustGatewaySettingsSettingsBlockPage;
    /**
    * DLP body scanning settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#body_scanning ZeroTrustGatewaySettings#body_scanning}
    */
    readonly bodyScanning?: ZeroTrustGatewaySettingsSettingsBodyScanning;
    /**
    * Browser isolation settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#browser_isolation ZeroTrustGatewaySettings#browser_isolation}
    */
    readonly browserIsolation?: ZeroTrustGatewaySettingsSettingsBrowserIsolation;
    /**
    * Certificate settings for Gateway TLS interception. If not specified, the Cloudflare Root CA will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#certificate ZeroTrustGatewaySettings#certificate}
    */
    readonly certificate?: ZeroTrustGatewaySettingsSettingsCertificate;
    /**
    * Custom certificate settings for BYO-PKI. (deprecated and replaced by `certificate`)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#custom_certificate ZeroTrustGatewaySettings#custom_certificate}
    */
    readonly customCertificate?: ZeroTrustGatewaySettingsSettingsCustomCertificate;
    /**
    * Extended e-mail matching settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#extended_email_matching ZeroTrustGatewaySettings#extended_email_matching}
    */
    readonly extendedEmailMatching?: ZeroTrustGatewaySettingsSettingsExtendedEmailMatching;
    /**
    * FIPS settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#fips ZeroTrustGatewaySettings#fips}
    */
    readonly fips?: ZeroTrustGatewaySettingsSettingsFips;
    /**
    * Setting to enable host selector in egress policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#host_selector ZeroTrustGatewaySettings#host_selector}
    */
    readonly hostSelector?: ZeroTrustGatewaySettingsSettingsHostSelector;
    /**
    * Protocol Detection settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#protocol_detection ZeroTrustGatewaySettings#protocol_detection}
    */
    readonly protocolDetection?: ZeroTrustGatewaySettingsSettingsProtocolDetection;
    /**
    * Sandbox settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#sandbox ZeroTrustGatewaySettings#sandbox}
    */
    readonly sandbox?: ZeroTrustGatewaySettingsSettingsSandbox;
    /**
    * TLS interception settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#tls_decrypt ZeroTrustGatewaySettings#tls_decrypt}
    */
    readonly tlsDecrypt?: ZeroTrustGatewaySettingsSettingsTlsDecrypt;
}
export declare function zeroTrustGatewaySettingsSettingsToTerraform(struct?: ZeroTrustGatewaySettingsSettings | cdktf.IResolvable): any;
export declare function zeroTrustGatewaySettingsSettingsToHclTerraform(struct?: ZeroTrustGatewaySettingsSettings | cdktf.IResolvable): any;
export declare class ZeroTrustGatewaySettingsSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSettings | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSettings | cdktf.IResolvable | undefined);
    private _activityLog;
    get activityLog(): ZeroTrustGatewaySettingsSettingsActivityLogOutputReference;
    putActivityLog(value: ZeroTrustGatewaySettingsSettingsActivityLog): void;
    resetActivityLog(): void;
    get activityLogInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsActivityLog | undefined;
    private _antivirus;
    get antivirus(): ZeroTrustGatewaySettingsSettingsAntivirusOutputReference;
    putAntivirus(value: ZeroTrustGatewaySettingsSettingsAntivirus): void;
    resetAntivirus(): void;
    get antivirusInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsAntivirus | undefined;
    private _appControlSettings;
    get appControlSettings(): ZeroTrustGatewaySettingsSettingsAppControlSettingsOutputReference;
    putAppControlSettings(value: ZeroTrustGatewaySettingsSettingsAppControlSettings): void;
    resetAppControlSettings(): void;
    get appControlSettingsInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsAppControlSettings | undefined;
    private _blockPage;
    get blockPage(): ZeroTrustGatewaySettingsSettingsBlockPageOutputReference;
    putBlockPage(value: ZeroTrustGatewaySettingsSettingsBlockPage): void;
    resetBlockPage(): void;
    get blockPageInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsBlockPage | undefined;
    private _bodyScanning;
    get bodyScanning(): ZeroTrustGatewaySettingsSettingsBodyScanningOutputReference;
    putBodyScanning(value: ZeroTrustGatewaySettingsSettingsBodyScanning): void;
    resetBodyScanning(): void;
    get bodyScanningInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsBodyScanning | undefined;
    private _browserIsolation;
    get browserIsolation(): ZeroTrustGatewaySettingsSettingsBrowserIsolationOutputReference;
    putBrowserIsolation(value: ZeroTrustGatewaySettingsSettingsBrowserIsolation): void;
    resetBrowserIsolation(): void;
    get browserIsolationInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsBrowserIsolation | undefined;
    private _certificate;
    get certificate(): ZeroTrustGatewaySettingsSettingsCertificateOutputReference;
    putCertificate(value: ZeroTrustGatewaySettingsSettingsCertificate): void;
    resetCertificate(): void;
    get certificateInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsCertificate | undefined;
    private _customCertificate;
    get customCertificate(): ZeroTrustGatewaySettingsSettingsCustomCertificateOutputReference;
    putCustomCertificate(value: ZeroTrustGatewaySettingsSettingsCustomCertificate): void;
    resetCustomCertificate(): void;
    get customCertificateInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsCustomCertificate | undefined;
    private _extendedEmailMatching;
    get extendedEmailMatching(): ZeroTrustGatewaySettingsSettingsExtendedEmailMatchingOutputReference;
    putExtendedEmailMatching(value: ZeroTrustGatewaySettingsSettingsExtendedEmailMatching): void;
    resetExtendedEmailMatching(): void;
    get extendedEmailMatchingInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsExtendedEmailMatching | undefined;
    private _fips;
    get fips(): ZeroTrustGatewaySettingsSettingsFipsOutputReference;
    putFips(value: ZeroTrustGatewaySettingsSettingsFips): void;
    resetFips(): void;
    get fipsInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsFips | undefined;
    private _hostSelector;
    get hostSelector(): ZeroTrustGatewaySettingsSettingsHostSelectorOutputReference;
    putHostSelector(value: ZeroTrustGatewaySettingsSettingsHostSelector): void;
    resetHostSelector(): void;
    get hostSelectorInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsHostSelector | undefined;
    private _protocolDetection;
    get protocolDetection(): ZeroTrustGatewaySettingsSettingsProtocolDetectionOutputReference;
    putProtocolDetection(value: ZeroTrustGatewaySettingsSettingsProtocolDetection): void;
    resetProtocolDetection(): void;
    get protocolDetectionInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsProtocolDetection | undefined;
    private _sandbox;
    get sandbox(): ZeroTrustGatewaySettingsSettingsSandboxOutputReference;
    putSandbox(value: ZeroTrustGatewaySettingsSettingsSandbox): void;
    resetSandbox(): void;
    get sandboxInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsSandbox | undefined;
    private _tlsDecrypt;
    get tlsDecrypt(): ZeroTrustGatewaySettingsSettingsTlsDecryptOutputReference;
    putTlsDecrypt(value: ZeroTrustGatewaySettingsSettingsTlsDecrypt): void;
    resetTlsDecrypt(): void;
    get tlsDecryptInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettingsTlsDecrypt | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings cloudflare_zero_trust_gateway_settings}
*/
export declare class ZeroTrustGatewaySettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_gateway_settings";
    /**
    * Generates CDKTF code for importing a ZeroTrustGatewaySettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustGatewaySettings to import
    * @param importFromId The id of the existing ZeroTrustGatewaySettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustGatewaySettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_gateway_settings cloudflare_zero_trust_gateway_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustGatewaySettingsConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustGatewaySettingsConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get createdAt(): string;
    get id(): string;
    private _settings;
    get settings(): ZeroTrustGatewaySettingsSettingsOutputReference;
    putSettings(value: ZeroTrustGatewaySettingsSettings): void;
    resetSettings(): void;
    get settingsInput(): cdktf.IResolvable | ZeroTrustGatewaySettingsSettings | undefined;
    get updatedAt(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
