/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustOrganizationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#account_id ZeroTrustOrganization#account_id}
    */
    readonly accountId?: string;
    /**
    * When set to true, users can authenticate via WARP for any application in your organization. Application settings will take precedence over this value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#allow_authenticate_via_warp ZeroTrustOrganization#allow_authenticate_via_warp}
    */
    readonly allowAuthenticateViaWarp?: boolean | cdktf.IResolvable;
    /**
    * The unique subdomain assigned to your Zero Trust organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#auth_domain ZeroTrustOrganization#auth_domain}
    */
    readonly authDomain?: string;
    /**
    * When set to `true`, users skip the identity provider selection step during login.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#auto_redirect_to_identity ZeroTrustOrganization#auto_redirect_to_identity}
    */
    readonly autoRedirectToIdentity?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#custom_pages ZeroTrustOrganization#custom_pages}
    */
    readonly customPages?: ZeroTrustOrganizationCustomPages;
    /**
    * Lock all settings as Read-Only in the Dashboard, regardless of user permission. Updates may only be made via the API or Terraform for this account when enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#is_ui_read_only ZeroTrustOrganization#is_ui_read_only}
    */
    readonly isUiReadOnly?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#login_design ZeroTrustOrganization#login_design}
    */
    readonly loginDesign?: ZeroTrustOrganizationLoginDesign;
    /**
    * The name of your Zero Trust organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#name ZeroTrustOrganization#name}
    */
    readonly name?: string;
    /**
    * The amount of time that tokens issued for applications will be valid. Must be in the format `300ms` or `2h45m`. Valid time units are: ns, us (or µs), ms, s, m, h.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#session_duration ZeroTrustOrganization#session_duration}
    */
    readonly sessionDuration?: string;
    /**
    * A description of the reason why the UI read only field is being toggled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#ui_read_only_toggle_reason ZeroTrustOrganization#ui_read_only_toggle_reason}
    */
    readonly uiReadOnlyToggleReason?: string;
    /**
    * The amount of time a user seat is inactive before it expires. When the user seat exceeds the set time of inactivity, the user is removed as an active seat and no longer counts against your Teams seat count.  Minimum value for this setting is 1 month (730h). Must be in the format `300ms` or `2h45m`. Valid time units are: `ns`, `us` (or `µs`), `ms`, `s`, `m`, `h`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#user_seat_expiration_inactive_time ZeroTrustOrganization#user_seat_expiration_inactive_time}
    */
    readonly userSeatExpirationInactiveTime?: string;
    /**
    * The amount of time that tokens issued for applications will be valid. Must be in the format `30m` or `2h45m`. Valid time units are: m, h.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#warp_auth_session_duration ZeroTrustOrganization#warp_auth_session_duration}
    */
    readonly warpAuthSessionDuration?: string;
    /**
    * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#zone_id ZeroTrustOrganization#zone_id}
    */
    readonly zoneId?: string;
}
export interface ZeroTrustOrganizationCustomPages {
    /**
    * The uid of the custom page to use when a user is denied access after failing a non-identity rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#forbidden ZeroTrustOrganization#forbidden}
    */
    readonly forbidden?: string;
    /**
    * The uid of the custom page to use when a user is denied access.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#identity_denied ZeroTrustOrganization#identity_denied}
    */
    readonly identityDenied?: string;
}
export declare function zeroTrustOrganizationCustomPagesToTerraform(struct?: ZeroTrustOrganizationCustomPages | cdktf.IResolvable): any;
export declare function zeroTrustOrganizationCustomPagesToHclTerraform(struct?: ZeroTrustOrganizationCustomPages | cdktf.IResolvable): any;
export declare class ZeroTrustOrganizationCustomPagesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustOrganizationCustomPages | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustOrganizationCustomPages | cdktf.IResolvable | undefined);
    private _forbidden?;
    get forbidden(): string;
    set forbidden(value: string);
    resetForbidden(): void;
    get forbiddenInput(): string | undefined;
    private _identityDenied?;
    get identityDenied(): string;
    set identityDenied(value: string);
    resetIdentityDenied(): void;
    get identityDeniedInput(): string | undefined;
}
export interface ZeroTrustOrganizationLoginDesign {
    /**
    * The background color on your login page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#background_color ZeroTrustOrganization#background_color}
    */
    readonly backgroundColor?: string;
    /**
    * The text at the bottom of your login page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#footer_text ZeroTrustOrganization#footer_text}
    */
    readonly footerText?: string;
    /**
    * The text at the top of your login page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#header_text ZeroTrustOrganization#header_text}
    */
    readonly headerText?: string;
    /**
    * The URL of the logo on your login page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#logo_path ZeroTrustOrganization#logo_path}
    */
    readonly logoPath?: string;
    /**
    * The text color on your login page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#text_color ZeroTrustOrganization#text_color}
    */
    readonly textColor?: string;
}
export declare function zeroTrustOrganizationLoginDesignToTerraform(struct?: ZeroTrustOrganizationLoginDesign | cdktf.IResolvable): any;
export declare function zeroTrustOrganizationLoginDesignToHclTerraform(struct?: ZeroTrustOrganizationLoginDesign | cdktf.IResolvable): any;
export declare class ZeroTrustOrganizationLoginDesignOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustOrganizationLoginDesign | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustOrganizationLoginDesign | cdktf.IResolvable | undefined);
    private _backgroundColor?;
    get backgroundColor(): string;
    set backgroundColor(value: string);
    resetBackgroundColor(): void;
    get backgroundColorInput(): string | undefined;
    private _footerText?;
    get footerText(): string;
    set footerText(value: string);
    resetFooterText(): void;
    get footerTextInput(): string | undefined;
    private _headerText?;
    get headerText(): string;
    set headerText(value: string);
    resetHeaderText(): void;
    get headerTextInput(): string | undefined;
    private _logoPath?;
    get logoPath(): string;
    set logoPath(value: string);
    resetLogoPath(): void;
    get logoPathInput(): string | undefined;
    private _textColor?;
    get textColor(): string;
    set textColor(value: string);
    resetTextColor(): void;
    get textColorInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization cloudflare_zero_trust_organization}
*/
export declare class ZeroTrustOrganization extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_organization";
    /**
    * Generates CDKTF code for importing a ZeroTrustOrganization resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustOrganization to import
    * @param importFromId The id of the existing ZeroTrustOrganization that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustOrganization to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zero_trust_organization cloudflare_zero_trust_organization} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustOrganizationConfig = {}
    */
    constructor(scope: Construct, id: string, config?: ZeroTrustOrganizationConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _allowAuthenticateViaWarp?;
    get allowAuthenticateViaWarp(): boolean | cdktf.IResolvable;
    set allowAuthenticateViaWarp(value: boolean | cdktf.IResolvable);
    resetAllowAuthenticateViaWarp(): void;
    get allowAuthenticateViaWarpInput(): boolean | cdktf.IResolvable | undefined;
    private _authDomain?;
    get authDomain(): string;
    set authDomain(value: string);
    resetAuthDomain(): void;
    get authDomainInput(): string | undefined;
    private _autoRedirectToIdentity?;
    get autoRedirectToIdentity(): boolean | cdktf.IResolvable;
    set autoRedirectToIdentity(value: boolean | cdktf.IResolvable);
    resetAutoRedirectToIdentity(): void;
    get autoRedirectToIdentityInput(): boolean | cdktf.IResolvable | undefined;
    get createdAt(): string;
    private _customPages;
    get customPages(): ZeroTrustOrganizationCustomPagesOutputReference;
    putCustomPages(value: ZeroTrustOrganizationCustomPages): void;
    resetCustomPages(): void;
    get customPagesInput(): cdktf.IResolvable | ZeroTrustOrganizationCustomPages | undefined;
    private _isUiReadOnly?;
    get isUiReadOnly(): boolean | cdktf.IResolvable;
    set isUiReadOnly(value: boolean | cdktf.IResolvable);
    resetIsUiReadOnly(): void;
    get isUiReadOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _loginDesign;
    get loginDesign(): ZeroTrustOrganizationLoginDesignOutputReference;
    putLoginDesign(value: ZeroTrustOrganizationLoginDesign): void;
    resetLoginDesign(): void;
    get loginDesignInput(): cdktf.IResolvable | ZeroTrustOrganizationLoginDesign | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _sessionDuration?;
    get sessionDuration(): string;
    set sessionDuration(value: string);
    resetSessionDuration(): void;
    get sessionDurationInput(): string | undefined;
    private _uiReadOnlyToggleReason?;
    get uiReadOnlyToggleReason(): string;
    set uiReadOnlyToggleReason(value: string);
    resetUiReadOnlyToggleReason(): void;
    get uiReadOnlyToggleReasonInput(): string | undefined;
    get updatedAt(): string;
    private _userSeatExpirationInactiveTime?;
    get userSeatExpirationInactiveTime(): string;
    set userSeatExpirationInactiveTime(value: string);
    resetUserSeatExpirationInactiveTime(): void;
    get userSeatExpirationInactiveTimeInput(): string | undefined;
    private _warpAuthSessionDuration?;
    get warpAuthSessionDuration(): string;
    set warpAuthSessionDuration(value: string);
    resetWarpAuthSessionDuration(): void;
    get warpAuthSessionDurationInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
