/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZoneDnssecConfig extends cdktf.TerraformMetaArguments {
    /**
    * If true, multi-signer DNSSEC is enabled on the zone, allowing multiple
    * providers to serve a DNSSEC-signed zone at the same time.
    * This is required for DNSKEY records (except those automatically
    * generated by Cloudflare) to be added to the zone.
    *
    * See [Multi-signer DNSSEC](https://developers.cloudflare.com/dns/dnssec/multi-signer-dnssec/) for details.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec#dnssec_multi_signer ZoneDnssec#dnssec_multi_signer}
    */
    readonly dnssecMultiSigner?: boolean | cdktf.IResolvable;
    /**
    * If true, allows Cloudflare to transfer in a DNSSEC-signed zone
    * including signatures from an external provider, without requiring
    * Cloudflare to sign any records on the fly.
    *
    * Note that this feature has some limitations.
    * See [Cloudflare as Secondary](https://developers.cloudflare.com/dns/zone-setups/zone-transfers/cloudflare-as-secondary/setup/#dnssec) for details.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec#dnssec_presigned ZoneDnssec#dnssec_presigned}
    */
    readonly dnssecPresigned?: boolean | cdktf.IResolvable;
    /**
    * If true, enables the use of NSEC3 together with DNSSEC on the zone.
    * Combined with setting dnssec_presigned to true, this enables the use of
    * NSEC3 records when transferring in from an external provider.
    * If dnssec_presigned is instead set to false (default), NSEC3 records will be
    * generated and signed at request time.
    *
    * See [DNSSEC with NSEC3](https://developers.cloudflare.com/dns/dnssec/enable-nsec3/) for details.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec#dnssec_use_nsec3 ZoneDnssec#dnssec_use_nsec3}
    */
    readonly dnssecUseNsec3?: boolean | cdktf.IResolvable;
    /**
    * Status of DNSSEC, based on user-desired state and presence of necessary records.
    * Available values: "active", "disabled".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec#status ZoneDnssec#status}
    */
    readonly status?: string;
    /**
    * Identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec#zone_id ZoneDnssec#zone_id}
    */
    readonly zoneId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec cloudflare_zone_dnssec}
*/
export declare class ZoneDnssec extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zone_dnssec";
    /**
    * Generates CDKTF code for importing a ZoneDnssec resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZoneDnssec to import
    * @param importFromId The id of the existing ZoneDnssec that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZoneDnssec to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_dnssec cloudflare_zone_dnssec} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZoneDnssecConfig
    */
    constructor(scope: Construct, id: string, config: ZoneDnssecConfig);
    get algorithm(): string;
    get digest(): string;
    get digestAlgorithm(): string;
    get digestType(): string;
    private _dnssecMultiSigner?;
    get dnssecMultiSigner(): boolean | cdktf.IResolvable;
    set dnssecMultiSigner(value: boolean | cdktf.IResolvable);
    resetDnssecMultiSigner(): void;
    get dnssecMultiSignerInput(): boolean | cdktf.IResolvable | undefined;
    private _dnssecPresigned?;
    get dnssecPresigned(): boolean | cdktf.IResolvable;
    set dnssecPresigned(value: boolean | cdktf.IResolvable);
    resetDnssecPresigned(): void;
    get dnssecPresignedInput(): boolean | cdktf.IResolvable | undefined;
    private _dnssecUseNsec3?;
    get dnssecUseNsec3(): boolean | cdktf.IResolvable;
    set dnssecUseNsec3(value: boolean | cdktf.IResolvable);
    resetDnssecUseNsec3(): void;
    get dnssecUseNsec3Input(): boolean | cdktf.IResolvable | undefined;
    get ds(): string;
    get flags(): number;
    get id(): string;
    get keyTag(): number;
    get keyType(): string;
    get modifiedOn(): string;
    get publicKey(): string;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
