/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZoneSubscriptionConfig extends cdktf.TerraformMetaArguments {
    /**
    * How often the subscription is renewed automatically.
    * Available values: "weekly", "monthly", "quarterly", "yearly".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#frequency ZoneSubscription#frequency}
    */
    readonly frequency?: string;
    /**
    * The rate plan applied to the subscription.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#rate_plan ZoneSubscription#rate_plan}
    */
    readonly ratePlan?: ZoneSubscriptionRatePlan;
    /**
    * Subscription identifier tag.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#zone_id ZoneSubscription#zone_id}
    */
    readonly zoneId: string;
}
export interface ZoneSubscriptionRatePlan {
    /**
    * The currency applied to the rate plan subscription.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#currency ZoneSubscription#currency}
    */
    readonly currency?: string;
    /**
    * Whether this rate plan is managed externally from Cloudflare.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#externally_managed ZoneSubscription#externally_managed}
    */
    readonly externallyManaged?: boolean | cdktf.IResolvable;
    /**
    * The ID of the rate plan.
    * Available values: "free", "lite", "pro", "pro_plus", "business", "enterprise", "partners_free", "partners_pro", "partners_business", "partners_enterprise".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#id ZoneSubscription#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether a rate plan is enterprise-based (or newly adopted term contract).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#is_contract ZoneSubscription#is_contract}
    */
    readonly isContract?: boolean | cdktf.IResolvable;
    /**
    * The full name of the rate plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#public_name ZoneSubscription#public_name}
    */
    readonly publicName?: string;
    /**
    * The scope that this rate plan applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#scope ZoneSubscription#scope}
    */
    readonly scope?: string;
    /**
    * The list of sets this rate plan applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#sets ZoneSubscription#sets}
    */
    readonly sets?: string[];
}
export declare function zoneSubscriptionRatePlanToTerraform(struct?: ZoneSubscriptionRatePlan | cdktf.IResolvable): any;
export declare function zoneSubscriptionRatePlanToHclTerraform(struct?: ZoneSubscriptionRatePlan | cdktf.IResolvable): any;
export declare class ZoneSubscriptionRatePlanOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZoneSubscriptionRatePlan | cdktf.IResolvable | undefined;
    set internalValue(value: ZoneSubscriptionRatePlan | cdktf.IResolvable | undefined);
    private _currency?;
    get currency(): string;
    set currency(value: string);
    resetCurrency(): void;
    get currencyInput(): string | undefined;
    private _externallyManaged?;
    get externallyManaged(): boolean | cdktf.IResolvable;
    set externallyManaged(value: boolean | cdktf.IResolvable);
    resetExternallyManaged(): void;
    get externallyManagedInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _isContract?;
    get isContract(): boolean | cdktf.IResolvable;
    set isContract(value: boolean | cdktf.IResolvable);
    resetIsContract(): void;
    get isContractInput(): boolean | cdktf.IResolvable | undefined;
    private _publicName?;
    get publicName(): string;
    set publicName(value: string);
    resetPublicName(): void;
    get publicNameInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _sets?;
    get sets(): string[];
    set sets(value: string[]);
    resetSets(): void;
    get setsInput(): string[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription cloudflare_zone_subscription}
*/
export declare class ZoneSubscription extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zone_subscription";
    /**
    * Generates CDKTF code for importing a ZoneSubscription resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZoneSubscription to import
    * @param importFromId The id of the existing ZoneSubscription that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZoneSubscription to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.6.0/docs/resources/zone_subscription cloudflare_zone_subscription} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZoneSubscriptionConfig
    */
    constructor(scope: Construct, id: string, config: ZoneSubscriptionConfig);
    get currency(): string;
    get currentPeriodEnd(): string;
    get currentPeriodStart(): string;
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
    get id(): string;
    get price(): number;
    private _ratePlan;
    get ratePlan(): ZoneSubscriptionRatePlanOutputReference;
    putRatePlan(value: ZoneSubscriptionRatePlan): void;
    resetRatePlan(): void;
    get ratePlanInput(): cdktf.IResolvable | ZoneSubscriptionRatePlan | undefined;
    get state(): string;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
